# CHANGELOG
## 2024.11.29 (2024-08-07)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.25.15 to 3.26.0

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.15 to 3.26.0.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/afb54ba388a7dca6ecae48f608c4ff05ff4cc77a...eb055d739abdc2e8de2e5f4ba1a8b246daa779aa)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`54a7b1f`](https://github.com/OZI-Project/blastpipe/commit/54a7b1fa6fcf6ff70411ab7507850ca6ce41f6ca))


### 🐛 Fixed Bugs

*  fix subproject msgspec — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`23dfe5f`](https://github.com/OZI-Project/blastpipe/commit/23dfe5fa1447d6d08a291121c1963e8e07f8e158))


### Other


* Merge pull request #141 from OZI-Project/dependabot/github_actions/github/codeql-action-3.26.0

⬆️ Bump github/codeql-action from 3.25.15 to 3.26.0
([`ca7cb30`](https://github.com/OZI-Project/blastpipe/commit/ca7cb304fded9ee645319fe03dfb55b2514a79cc))

## 2024.11.28 (2024-08-07)


### 🐛 Fixed Bugs

* (msgspec): ``install-subprojects=enabled`` — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`561280f`](https://github.com/OZI-Project/blastpipe/commit/561280f4dc17d2f53887365b78657a6db33a47cc))


### ✏️ Corrected Typos

*  ``install-subprojects=enabled`` — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`e9e765b`](https://github.com/OZI-Project/blastpipe/commit/e9e765b24a585200a322434eca9ba5623438d897))

## 2024.11.27 (2024-08-07)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/release from 0.7.3 to 0.7.4

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.7.3 to 0.7.4.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/b2388e2a058926646944ddc471737e2e6495940d...a35f144432e2de0e30f800777676c652ea9c043b)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`4d27f7b`](https://github.com/OZI-Project/blastpipe/commit/4d27f7b7c25b890bff90e4f8310964086fdb1cfa))

*  Bump OZI-Project/checkpoint from 0.5.0 to 0.5.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.5.0 to 0.5.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/8b8d7d173139c115188e4689204aba4e36e98810...bfd6e529455ff6ec099bfd16be2ab86fa0332a71)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`ceed737`](https://github.com/OZI-Project/blastpipe/commit/ceed7378e356d77714c1fbeb94b71dfe58d9de4f))

*  Bump actions/upload-artifact from 4.3.5 to 4.3.6

Bumps [actions/upload-artifact](https://github.com/actions/upload-artifact) from 4.3.5 to 4.3.6.
- [Release notes](https://github.com/actions/upload-artifact/releases)
- [Commits](https://github.com/actions/upload-artifact/compare/89ef406dd8d7e03cfd12d9e0a4a378f454709029...834a144ee995460fba8ed112a2fc961b36a5ec5a)


updated-dependencies:
- dependency-name: actions/upload-artifact
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`2ddc19e`](https://github.com/OZI-Project/blastpipe/commit/2ddc19e6a7df7ccb35ddbe2dbc1ed3582b7b3227))

*  Bump OZI-Project/draft from 0.3.7 to 0.3.8

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.7 to 0.3.8.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/f9e3ee38f76e3aefcbf29743e9ec64f716182001...38dfc0df2b189018bbae0b016c61ac1d704c2626)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`486f10b`](https://github.com/OZI-Project/blastpipe/commit/486f10bfbda2235c34d46c0031efbf929482c6b6))

*  Bump step-security/harden-runner from 2.9.0 to 2.9.1

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.9.0 to 2.9.1.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/0d381219ddf674d61a7572ddd19d7941e271515c...5c7944e73c4c2a096b17a9cb74d65b6c2bbafbde)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`28170ab`](https://github.com/OZI-Project/blastpipe/commit/28170ab6eaf60388b197e0e9acde023080a7e43b))

*  Bump actions/upload-artifact from 4.3.4 to 4.3.5

Bumps [actions/upload-artifact](https://github.com/actions/upload-artifact) from 4.3.4 to 4.3.5.
- [Release notes](https://github.com/actions/upload-artifact/releases)
- [Commits](https://github.com/actions/upload-artifact/compare/0b2256b8c012f0828dc542b3febcab082c67f72b...89ef406dd8d7e03cfd12d9e0a4a378f454709029)


updated-dependencies:
- dependency-name: actions/upload-artifact
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`fc630b9`](https://github.com/OZI-Project/blastpipe/commit/fc630b9e93a57dbe769a32d8c987e2f164826119))


### 🔨 Updated Scripts

*  add msgspec distribution to build — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`860fccd`](https://github.com/OZI-Project/blastpipe/commit/860fccd986003928a2ec9e2aea146d93f8d60f3a))


### Other


* Merge pull request #136 from OZI-Project/dependabot/github_actions/OZI-Project/release-0.7.4

⬆️ Bump OZI-Project/release from 0.7.3 to 0.7.4
([`0d6532b`](https://github.com/OZI-Project/blastpipe/commit/0d6532b1c6792b6b59c6c72b388336d10968a341))

* Merge pull request #137 from OZI-Project/dependabot/github_actions/OZI-Project/checkpoint-0.5.1

⬆️ Bump OZI-Project/checkpoint from 0.5.0 to 0.5.1
([`a78b487`](https://github.com/OZI-Project/blastpipe/commit/a78b4870430e3ac00decbaf8d07d6368d9873546))

* Merge pull request #138 from OZI-Project/dependabot/github_actions/actions/upload-artifact-4.3.6

⬆️ Bump actions/upload-artifact from 4.3.5 to 4.3.6
([`539a2f3`](https://github.com/OZI-Project/blastpipe/commit/539a2f33211a3c0fc26328041be8bcb8e84ac956))

* Merge pull request #139 from OZI-Project/dependabot/github_actions/OZI-Project/draft-0.3.8

⬆️ Bump OZI-Project/draft from 0.3.7 to 0.3.8
([`a468b0c`](https://github.com/OZI-Project/blastpipe/commit/a468b0c2ffad0d6e02b1808bfea28f34d1021cbc))

* Merge pull request #140 from OZI-Project/dependabot/github_actions/step-security/harden-runner-2.9.1

⬆️ Bump step-security/harden-runner from 2.9.0 to 2.9.1
([`8e38338`](https://github.com/OZI-Project/blastpipe/commit/8e38338ebbfdec62ae192b2ac10dfd8e547e3269))

* Merge pull request #135 from OZI-Project/dependabot/github_actions/actions/upload-artifact-4.3.5

⬆️ Bump actions/upload-artifact from 4.3.4 to 4.3.5
([`69c477b`](https://github.com/OZI-Project/blastpipe/commit/69c477ba19fe8163618f510cc4cbd1da55f6ba2c))

## 2024.11.26 (2024-07-30)


### ⬆️ Upgraded Dependencies

*  Bump ossf/scorecard-action from 2.3.3 to 2.4.0

Bumps [ossf/scorecard-action](https://github.com/ossf/scorecard-action) from 2.3.3 to 2.4.0.
- [Release notes](https://github.com/ossf/scorecard-action/releases)
- [Changelog](https://github.com/ossf/scorecard-action/blob/main/RELEASE.md)
- [Commits](https://github.com/ossf/scorecard-action/compare/dc50aa9510b46c811795eb24b2f1ba02a914e534...62b2cac7ed8198b15735ed49ab1e5cf35480ba46)


updated-dependencies:
- dependency-name: ossf/scorecard-action
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`85df8da`](https://github.com/OZI-Project/blastpipe/commit/85df8dabeebd7a76df5e9e8c2da55a069884646c))


### Other


* Merge pull request #134 from OZI-Project/dependabot/github_actions/ossf/scorecard-action-2.4.0

⬆️ Bump ossf/scorecard-action from 2.3.3 to 2.4.0
([`2c4fc56`](https://github.com/OZI-Project/blastpipe/commit/2c4fc56443375799b425eb3d78668ed5581bdd9c))

## 2024.11.25 (2024-07-26)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.25.14 to 3.25.15

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.14 to 3.25.15.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/5cf07d8b700b67e235fbb65cbc84f69c0cf10464...afb54ba388a7dca6ecae48f608c4ff05ff4cc77a)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`0e867fb`](https://github.com/OZI-Project/blastpipe/commit/0e867fb7b8deed01e7a9d09065c2bbadd9f9aeec))


### Other


* Merge pull request #133 from OZI-Project/dependabot/github_actions/github/codeql-action-3.25.15

⬆️ Bump github/codeql-action from 3.25.14 to 3.25.15
([`55686bf`](https://github.com/OZI-Project/blastpipe/commit/55686bf075898f2ac3bf6d45fb77bad7dba761c9))

## 2024.11.24 (2024-07-26)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.25.13 to 3.25.14

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.13 to 3.25.14.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/2d790406f505036ef40ecba973cc774a50395aac...5cf07d8b700b67e235fbb65cbc84f69c0cf10464)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`9f87184`](https://github.com/OZI-Project/blastpipe/commit/9f87184e81b3025ea04c53b919ff156d4fb7ed90))

*  Bump OZI-Project/publish from 0.1.8 to 0.1.9

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.8 to 0.1.9.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/798954a5a38220573d0a8c2873b5b08d1059d237...e53fb3caac6d0530d1cc3d05d0c3e3a6b6fb1c67)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`e83475f`](https://github.com/OZI-Project/blastpipe/commit/e83475f3bfc75ad4c087f5c3c92a45ea39a11739))

*  Bump OZI-Project/draft from 0.3.6 to 0.3.7

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.6 to 0.3.7.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/29d09f8b7b490a3be3b6a448f1f40864fe1c7b25...f9e3ee38f76e3aefcbf29743e9ec64f716182001)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`ad8cd36`](https://github.com/OZI-Project/blastpipe/commit/ad8cd36973e69b06aae0bfbfdbe8ee6259ec209f))


### Other


* Merge pull request #132 from OZI-Project/dependabot/github_actions/github/codeql-action-3.25.14

⬆️ Bump github/codeql-action from 3.25.13 to 3.25.14
([`8c8aa9c`](https://github.com/OZI-Project/blastpipe/commit/8c8aa9c0a60135c94e8b1e6ef889ae0601e181e0))

* Merge pull request #130 from OZI-Project/dependabot/github_actions/OZI-Project/publish-0.1.9

⬆️ Bump OZI-Project/publish from 0.1.8 to 0.1.9
([`9b765a7`](https://github.com/OZI-Project/blastpipe/commit/9b765a7993ad8236ddc897b95898f9a8fde79882))

* Merge pull request #131 from OZI-Project/dependabot/github_actions/OZI-Project/draft-0.3.7

⬆️ Bump OZI-Project/draft from 0.3.6 to 0.3.7
([`fa68c50`](https://github.com/OZI-Project/blastpipe/commit/fa68c50d6b18ce04d959b37437b1b7b0f797d0cd))

## 2024.11.23 (2024-07-19)


### ⬆️ Upgraded Dependencies

*  Bump step-security/harden-runner from 2.8.1 to 2.9.0

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.8.1 to 2.9.0.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/17d0e2bd7d51742c71671bd19fa12bdc9d40a3d6...0d381219ddf674d61a7572ddd19d7941e271515c)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`87ba76d`](https://github.com/OZI-Project/blastpipe/commit/87ba76d3523e75dd882701c7c66561fd87c92a76))

*  Bump github/codeql-action from 3.25.12 to 3.25.13

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.12 to 3.25.13.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/4fa2a7953630fd2f3fb380f21be14ede0169dd4f...2d790406f505036ef40ecba973cc774a50395aac)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`e643d73`](https://github.com/OZI-Project/blastpipe/commit/e643d73d6adde9671e239dedb37050d6a84babfe))


### Other


* Merge pull request #128 from OZI-Project/dependabot/github_actions/step-security/harden-runner-2.9.0

⬆️ Bump step-security/harden-runner from 2.8.1 to 2.9.0
([`2ca707c`](https://github.com/OZI-Project/blastpipe/commit/2ca707cbd3c3c2f7394d3333bd401127373b7e94))

* Merge pull request #129 from OZI-Project/dependabot/github_actions/github/codeql-action-3.25.13

⬆️ Bump github/codeql-action from 3.25.12 to 3.25.13
([`61a9ecb`](https://github.com/OZI-Project/blastpipe/commit/61a9ecb7a5b63abc06a4f24774b2d257f5c4764f))

## 2024.11.22 (2024-07-18)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/checkpoint from 0.4.3 to 0.5.0

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.4.3 to 0.5.0.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/bfd00dbaebfc8e86f730575dd907eb043052e795...8b8d7d173139c115188e4689204aba4e36e98810)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`599840b`](https://github.com/OZI-Project/blastpipe/commit/599840b7fa73d7bc2fb19e7e83ee4891992821ba))

*  Bump OZI-Project/draft from 0.3.5 to 0.3.6

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.5 to 0.3.6.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/8b8bafcce0442b4f6985d364c27030e44648e998...29d09f8b7b490a3be3b6a448f1f40864fe1c7b25)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`b830549`](https://github.com/OZI-Project/blastpipe/commit/b8305493d38ed311f7779737e586a397247e7aec))

*  Bump OZI-Project/release from 0.6.6 to 0.7.0

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.6.6 to 0.7.0.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/de8cb06cabbdc0697678bb16091258e8cc2e8f34...5504420a55b9ce92a9c927b6508231b1c1abd00c)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`c3eec0f`](https://github.com/OZI-Project/blastpipe/commit/c3eec0f09a807edfe1fe0c9893abd85447106e3f))


### 📌 Pinned Dependencies

*  OZI-Project/release@0.7.3 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`14ff1c2`](https://github.com/OZI-Project/blastpipe/commit/14ff1c2750b70d2381f95b3d1d99a63eee9902b5))

*  OZI-Project/release@0.7.2 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`39602c8`](https://github.com/OZI-Project/blastpipe/commit/39602c85a0ce68da8bae0c5d24d459458e00f5ec))

*  OZI-Project/release@0.7.1 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`3e3bb8f`](https://github.com/OZI-Project/blastpipe/commit/3e3bb8f9cbd08b90078e8744018a647c92dbddd6))


### Other


* Merge pull request #125 from OZI-Project/dependabot/github_actions/OZI-Project/checkpoint-0.5.0

⬆️ Bump OZI-Project/checkpoint from 0.4.3 to 0.5.0
([`64ec987`](https://github.com/OZI-Project/blastpipe/commit/64ec987053b102fb6657bb3b7c6a7faff03bb9b7))

* Merge pull request #126 from OZI-Project/dependabot/github_actions/OZI-Project/draft-0.3.6

⬆️ Bump OZI-Project/draft from 0.3.5 to 0.3.6
([`530707b`](https://github.com/OZI-Project/blastpipe/commit/530707b667a8d85d714ccd8a4397366a5c5bae83))

* Merge pull request #127 from OZI-Project/dependabot/github_actions/OZI-Project/release-0.7.0

⬆️ Bump OZI-Project/release from 0.6.6 to 0.7.0
([`68db5a6`](https://github.com/OZI-Project/blastpipe/commit/68db5a62dcd68a851aa68444fff01dd26d3959c7))

## 2024.11.21 (2024-07-18)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/release from 0.6.5 to 0.6.6

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.6.5 to 0.6.6.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/f99b4e470f3dc50884d227dff38c18c3f0f3f927...de8cb06cabbdc0697678bb16091258e8cc2e8f34)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`68386ce`](https://github.com/OZI-Project/blastpipe/commit/68386ce00dc07866f640924499d951f7a68fc7b9))

*  Bump OZI-Project/publish from 0.1.7 to 0.1.8

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.7 to 0.1.8.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/1d1a105c970d1600a544bf67b93ef09fefe722cf...798954a5a38220573d0a8c2873b5b08d1059d237)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`ea9b07c`](https://github.com/OZI-Project/blastpipe/commit/ea9b07c024f7bc0f6453313bc06ea22444475c5c))

*  Bump OZI-Project/draft from 0.3.4 to 0.3.5

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.4 to 0.3.5.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/58ae20c3cd6b2754a602bb4315bc80eee6c9d495...8b8bafcce0442b4f6985d364c27030e44648e998)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`1ba314d`](https://github.com/OZI-Project/blastpipe/commit/1ba314da54d60c892196aa620461dbc1596d5b57))

*  Bump OZI-Project/checkpoint from 0.4.2 to 0.4.3

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.4.2 to 0.4.3.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/f8acf37d2479db59d191e5f6324758e224149bd0...bfd00dbaebfc8e86f730575dd907eb043052e795)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`ab0487e`](https://github.com/OZI-Project/blastpipe/commit/ab0487e53a1f1089ea3f30ebe9cc85978ce52993))


### Other


* Merge pull request #122 from OZI-Project/dependabot/github_actions/OZI-Project/release-0.6.6

⬆️ Bump OZI-Project/release from 0.6.5 to 0.6.6
([`8c8cfd5`](https://github.com/OZI-Project/blastpipe/commit/8c8cfd532355dc49e40e9ff066e0ef7c40d0bcf4))

* Merge pull request #121 from OZI-Project/dependabot/github_actions/OZI-Project/publish-0.1.8

⬆️ Bump OZI-Project/publish from 0.1.7 to 0.1.8
([`62bbae9`](https://github.com/OZI-Project/blastpipe/commit/62bbae90575b6812b68176019aba6fab3ca4462b))

* Merge pull request #123 from OZI-Project/dependabot/github_actions/OZI-Project/draft-0.3.5

⬆️ Bump OZI-Project/draft from 0.3.4 to 0.3.5
([`359a1f5`](https://github.com/OZI-Project/blastpipe/commit/359a1f5d07a9dc3573eb3337c0e2655be275613d))

* Merge pull request #124 from OZI-Project/dependabot/github_actions/OZI-Project/checkpoint-0.4.3

⬆️ Bump OZI-Project/checkpoint from 0.4.2 to 0.4.3
([`5e68cd0`](https://github.com/OZI-Project/blastpipe/commit/5e68cd073c8810c29054dea22f29c94cf1fc481c))

## 2024.11.20 (2024-07-18)


### 📌 Pinned Dependencies

*  OZI.build&gt;=0.0.27 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`acf5346`](https://github.com/OZI-Project/blastpipe/commit/acf534654e5b6b83d0615619071ee12d8ad088d0))

## 2024.11.19 (2024-07-13)


### ⬆️ Upgraded Dependencies

*  Bump actions/dependency-review-action from 4.3.3 to 4.3.4

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.3.3 to 4.3.4.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/72eb03d02c7872a771aacd928f3123ac62ad6d3a...5a2ce3f5b92ee19cbb1541a4984c76d921601d7c)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`2cb63c0`](https://github.com/OZI-Project/blastpipe/commit/2cb63c05007522e36538fa318d4a22d30c99b8fc))

*  Bump github/codeql-action from 3.25.11 to 3.25.12

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.11 to 3.25.12.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/b611370bb5703a7efb587f9d136a52ea24c5c38c...4fa2a7953630fd2f3fb380f21be14ede0169dd4f)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`63af6b0`](https://github.com/OZI-Project/blastpipe/commit/63af6b08d12cada2c924396e28eb9acca079c7d0))


### Other


* Merge pull request #119 from OZI-Project/dependabot/github_actions/actions/dependency-review-action-4.3.4

⬆️ Bump actions/dependency-review-action from 4.3.3 to 4.3.4
([`8232958`](https://github.com/OZI-Project/blastpipe/commit/8232958f4c4ef546be419d452ef63d7b36acc436))

* Merge pull request #120 from OZI-Project/dependabot/github_actions/github/codeql-action-3.25.12

⬆️ Bump github/codeql-action from 3.25.11 to 3.25.12
([`d90ea0c`](https://github.com/OZI-Project/blastpipe/commit/d90ea0c22e1968760e7c97b20087b72bda377767))

## 2024.11.18 (2024-07-08)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/publish from 0.1.6 to 0.1.7

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.6 to 0.1.7.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/5f82de29a76b1befa60a5b99752a881a83aeed47...1d1a105c970d1600a544bf67b93ef09fefe722cf)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`4b0289a`](https://github.com/OZI-Project/blastpipe/commit/4b0289ae5d792fd349760d3bfe552946e8eb8c7d))

*  Bump OZI-Project/draft from 0.3.3 to 0.3.4

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.3 to 0.3.4.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1662727a1f63e3344fc5bda22ff785083596c8c3...58ae20c3cd6b2754a602bb4315bc80eee6c9d495)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`ce478ca`](https://github.com/OZI-Project/blastpipe/commit/ce478caaaaafba9b7f1d2eb5adaa32b7a6026f6e))


### Other


* Merge pull request #117 from OZI-Project/dependabot/github_actions/OZI-Project/publish-0.1.7

⬆️ Bump OZI-Project/publish from 0.1.6 to 0.1.7
([`a681969`](https://github.com/OZI-Project/blastpipe/commit/a681969b5f5ec9f101a3fc4bd5688c65ce1d1938))

* Merge pull request #118 from OZI-Project/dependabot/github_actions/OZI-Project/draft-0.3.4

⬆️ Bump OZI-Project/draft from 0.3.3 to 0.3.4
([`545c764`](https://github.com/OZI-Project/blastpipe/commit/545c764063fcb7fbb3caf799a7d65e5e14730368))

## 2024.11.17 (2024-07-06)


### ⬆️ Upgraded Dependencies

*  Bump actions/upload-artifact from 4.3.3 to 4.3.4

Bumps [actions/upload-artifact](https://github.com/actions/upload-artifact) from 4.3.3 to 4.3.4.
- [Release notes](https://github.com/actions/upload-artifact/releases)
- [Commits](https://github.com/actions/upload-artifact/compare/65462800fd760344b1a7b4382951275a0abb4808...0b2256b8c012f0828dc542b3febcab082c67f72b)


updated-dependencies:
- dependency-name: actions/upload-artifact
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`401b2ba`](https://github.com/OZI-Project/blastpipe/commit/401b2bac9928ddc7b42cfcf79539ad7899664549))


### Other


* Merge pull request #116 from OZI-Project/dependabot/github_actions/actions/upload-artifact-4.3.4

⬆️ Bump actions/upload-artifact from 4.3.3 to 4.3.4
([`772c5b5`](https://github.com/OZI-Project/blastpipe/commit/772c5b5e770f940ead372706a5dfe911877afbb2))

## 2024.11.16 (2024-07-03)


### 🐛 Fixed Bugs

* 📝 fix changelog duplicated commit type headings — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`61a7016`](https://github.com/OZI-Project/blastpipe/commit/61a7016b0d5870e084429fa8ce99a2b33fa9fc09))

## 2024.11.15 (2024-07-03)


### 🚸 Improved Usability

*  remove CHANGELOG.md from build files — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`b0b9a79`](https://github.com/OZI-Project/blastpipe/commit/b0b9a79f5eb1c91bf960edc1a4fd59f7c23d57e4))


### Other


* Merge branch &#39;main&#39; of https://github.com/rjdbcm/blastpipe
([`dc645ce`](https://github.com/OZI-Project/blastpipe/commit/dc645ce3ce28ade38eb1870f34112e73cdbae333))

## 2024.11.14 (2024-07-03)


### 🚸 Improved Usability

*  remove CHANGELOG.md from build files — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`f6d23c0`](https://github.com/OZI-Project/blastpipe/commit/f6d23c0bc44779981dab0650f95fdf293c9b739d))

*  add CHANGELOG template — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`ba5de4f`](https://github.com/OZI-Project/blastpipe/commit/ba5de4f30c0af613ec4523e8bb0c27629bff9e2a))

## 2024.11.13 (2024-07-02)


### 🔥 Deleted Code or Files

*  remove ozi-templates remnants — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`f7cfc4c`](https://github.com/OZI-Project/blastpipe/commit/f7cfc4c4dde5a208e8ef670f12cc942a5f2a78f4))


### Other


* Merge pull request #115 from OZI-Project/dependabot/github_actions/github/codeql-action-3.25.11

Bump github/codeql-action from 3.25.10 to 3.25.11
([`188f241`](https://github.com/OZI-Project/blastpipe/commit/188f24115a81b81c8503491a244ec5474ca2b262))

* Bump github/codeql-action from 3.25.10 to 3.25.11

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.10 to 3.25.11.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/23acc5c183826b7a8a97bce3cecc52db901f8251...b611370bb5703a7efb587f9d136a52ea24c5c38c)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`9398b9a`](https://github.com/OZI-Project/blastpipe/commit/9398b9a6bc1d6a98d5bb804cb060341d6cfd257d))

## 2024.11.12 (2024-06-29)


### 🚸 Improved Usability

* (ozi_templates): remove historical template files from build — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`01d6bd6`](https://github.com/OZI-Project/blastpipe/commit/01d6bd6e874b890219a1ede381587efd2765d3bd))


### 🔥 Deleted Code or Files

* remove test_filter.py — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`dc6dce6`](https://github.com/OZI-Project/blastpipe/commit/dc6dce66f29d456a20429bec614a5ea59f3025ef))

* remove test_filter.py — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`9ea52ce`](https://github.com/OZI-Project/blastpipe/commit/9ea52ce5f8bf982403da44b997ffe82df600e318))


### 📌 Pinned Dependencies

*  OZI.build~=0.0.26 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`ffa78c6`](https://github.com/OZI-Project/blastpipe/commit/ffa78c615b4785fc9c7811f9c1c6dbfbacf451fa))


### Other


* Merge branch &#39;main&#39; of https://github.com/rjdbcm/blastpipe
([`809c03f`](https://github.com/OZI-Project/blastpipe/commit/809c03fe814dac012a94ec24e417f3934e8d5477))

## 2024.11.11 (2024-06-26)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/draft from 0.3.2 to 0.3.3

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.2 to 0.3.3.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/4cb9feb842df0dcd1e48c0f64f3b61e0ac64f05d...1662727a1f63e3344fc5bda22ff785083596c8c3)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`aadf55e`](https://github.com/OZI-Project/blastpipe/commit/aadf55eaca4350de32348169f6ca0606823c1f04))

*  Bump OZI-Project/publish from 0.1.5 to 0.1.6

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.5 to 0.1.6.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/edb7e48d4196153b8dabddb970405495e1ff2092...5f82de29a76b1befa60a5b99752a881a83aeed47)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`70a40df`](https://github.com/OZI-Project/blastpipe/commit/70a40df897aa8a9587ecfd18f8192e4cc07fe218))

*  Bump OZI-Project/release from 0.6.4 to 0.6.5

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.6.4 to 0.6.5.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/cfe06ef22488ee71ba4f2807b16bbdba1a6fb26f...f99b4e470f3dc50884d227dff38c18c3f0f3f927)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`c6703d0`](https://github.com/OZI-Project/blastpipe/commit/c6703d01430d9a8b817cae185f8e157a23d41364))


### Other


* Merge pull request #113 from OZI-Project/dependabot/github_actions/OZI-Project/draft-0.3.3

⬆️ Bump OZI-Project/draft from 0.3.2 to 0.3.3
([`513e195`](https://github.com/OZI-Project/blastpipe/commit/513e1954d26af57ccf0de73aa9fcdcc7730f11f0))

* Merge pull request #114 from OZI-Project/dependabot/github_actions/OZI-Project/publish-0.1.6

⬆️ Bump OZI-Project/publish from 0.1.5 to 0.1.6
([`c42a3f2`](https://github.com/OZI-Project/blastpipe/commit/c42a3f29683e0411c488cda8b532b439782f5520))

* Merge pull request #112 from OZI-Project/dependabot/github_actions/OZI-Project/release-0.6.5

⬆️ Bump OZI-Project/release from 0.6.4 to 0.6.5
([`01586d4`](https://github.com/OZI-Project/blastpipe/commit/01586d440e707048c39322548342741a2a748c48))

## 2024.11.10 (2024-06-16)


### 🐛 Fixed Bugs

*  FIX missing installed files in wheels — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`6c91a6e`](https://github.com/OZI-Project/blastpipe/commit/6c91a6ef6a741fcce525169dd9881053185cd8ac))

## 2024.11.9 (2024-06-16)


### ⬆️ Upgraded Dependencies

*  OZI.build&gt;=0.0.24 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`0c5ceae`](https://github.com/OZI-Project/blastpipe/commit/0c5ceaea791ff1c4098f3523c3aca326c026ca82))

## 2024.11.8 (2024-06-16)


### 🐛 Fixed Bugs

*  fix args for release, publish, and readme-renderer.meson.options templates — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`1bdb09c`](https://github.com/OZI-Project/blastpipe/commit/1bdb09c89eb1af98626b0826e9d44ac3f6424d60))

## 2024.11.7 (2024-06-15)


### 🐛 Fixed Bugs

*  checkpoint template no longer requires prerelease python — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`d73c40f`](https://github.com/OZI-Project/blastpipe/commit/d73c40f1748372158fe9fd5ff8524c85f9602e9e))

## 2024.11.6 (2024-06-14)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/draft from 0.3.1 to 0.3.2

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.1 to 0.3.2.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/f136e6eb55507553aee04e92455cc2dc279583fc...4cb9feb842df0dcd1e48c0f64f3b61e0ac64f05d)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`dbc4948`](https://github.com/OZI-Project/blastpipe/commit/dbc4948282a79e5d01cb26bfd932c8cb97ff9a4d))

*  Bump OZI-Project/checkpoint from 0.4.1 to 0.4.2

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.4.1 to 0.4.2.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/6cc6de3235d61a5bae47fa03e773a2af9a985016...f8acf37d2479db59d191e5f6324758e224149bd0)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`8336a98`](https://github.com/OZI-Project/blastpipe/commit/8336a98fc4008d468b27b3e186fb7779287027d8))


### Other


* Merge pull request #110 from OZI-Project/dependabot/github_actions/OZI-Project/draft-0.3.2

⬆️ Bump OZI-Project/draft from 0.3.1 to 0.3.2
([`6d2923c`](https://github.com/OZI-Project/blastpipe/commit/6d2923cf9b4c3a4d180bcfe004972299e3485ed1))

* Merge pull request #111 from OZI-Project/dependabot/github_actions/OZI-Project/checkpoint-0.4.2

⬆️ Bump OZI-Project/checkpoint from 0.4.1 to 0.4.2
([`7cbcecf`](https://github.com/OZI-Project/blastpipe/commit/7cbcecf5427c63a82f6038b104e973fc83994ba1))

## 2024.11.5 (2024-06-14)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.25.8 to 3.25.10

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.8 to 3.25.10.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/2e230e8fe0ad3a14a340ad0815ddb96d599d2aff...23acc5c183826b7a8a97bce3cecc52db901f8251)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`a0817b0`](https://github.com/OZI-Project/blastpipe/commit/a0817b0cb439677c901522de60666503e632e7b3))

*  Bump OZI-Project/release from 0.6.0 to 0.6.4

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.6.0 to 0.6.4.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/4f6d83ec6fd65e43f393bb7797b7a8a9a882de22...cfe06ef22488ee71ba4f2807b16bbdba1a6fb26f)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`0ee7354`](https://github.com/OZI-Project/blastpipe/commit/0ee7354d95e0d715bf30ed9e44fce2867c7fd2e7))

*  Bump actions/checkout from 4.1.6 to 4.1.7

Bumps [actions/checkout](https://github.com/actions/checkout) from 4.1.6 to 4.1.7.
- [Release notes](https://github.com/actions/checkout/releases)
- [Changelog](https://github.com/actions/checkout/blob/main/CHANGELOG.md)
- [Commits](https://github.com/actions/checkout/compare/a5ac7e51b41094c92402da3b24376905380afc29...692973e3d937129bcbf40652eb9f2f61becf3332)


updated-dependencies:
- dependency-name: actions/checkout
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`fad4165`](https://github.com/OZI-Project/blastpipe/commit/fad41656008bcfb6ed41f1bad092c0a030910084))

*  Bump OZI-Project/checkpoint from 0.4.0 to 0.4.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.4.0 to 0.4.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/64e790c506ba8df435c545f0d4135fbfde23f6a0...6cc6de3235d61a5bae47fa03e773a2af9a985016)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`5cdd21e`](https://github.com/OZI-Project/blastpipe/commit/5cdd21eca3ca9eece7bc597940f3bb50b1b9591e))


### Other


* Merge pull request #108 from OZI-Project/dependabot/github_actions/github/codeql-action-3.25.10

⬆️ Bump github/codeql-action from 3.25.8 to 3.25.10
([`d1abe37`](https://github.com/OZI-Project/blastpipe/commit/d1abe379924b370d35d46f207d2f44b72fad8c1a))

* Merge pull request #106 from OZI-Project/dependabot/github_actions/OZI-Project/release-0.6.4

⬆️ Bump OZI-Project/release from 0.6.0 to 0.6.4
([`18de8b6`](https://github.com/OZI-Project/blastpipe/commit/18de8b6fb34195e7be8f9263ac50f46973ee3c2f))

* Merge pull request #107 from OZI-Project/dependabot/github_actions/actions/checkout-4.1.7

⬆️ Bump actions/checkout from 4.1.6 to 4.1.7
([`3129a32`](https://github.com/OZI-Project/blastpipe/commit/3129a326b9969e1f951affe590807cac406bd1cb))

* Merge pull request #109 from OZI-Project/dependabot/github_actions/OZI-Project/checkpoint-0.4.1

⬆️ Bump OZI-Project/checkpoint from 0.4.0 to 0.4.1
([`3c46c27`](https://github.com/OZI-Project/blastpipe/commit/3c46c27a8433a066926aada1b4203a7382938fd9))

## 2024.11.4 (2024-06-13)


### 🔨 Updated Scripts

* (cleanup.yml.j2): ``permissions: read-all`` — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`65ccb9c`](https://github.com/OZI-Project/blastpipe/commit/65ccb9cef8b4673fe4813bd84f6fa02cb7f70fac))

## 2024.11.3 (2024-06-13)


### Other


* Merge branch &#39;main&#39; of https://github.com/rjdbcm/blastpipe
([`198e8c5`](https://github.com/OZI-Project/blastpipe/commit/198e8c5eb1b40f71e4adeef30bb04e05fdb1b6df))

## 2024.11.2 (2024-06-12)


### 🔨 Updated Scripts

* (cleanup): add id-token, contents, actions write permission — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`e5bd26e`](https://github.com/OZI-Project/blastpipe/commit/e5bd26e53da78c72f050eb647508ab2b3a1dafa3))

*  harden cleanup template — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`1a71c50`](https://github.com/OZI-Project/blastpipe/commit/1a71c50897dc4a2615a2a47c2b969b9ee06a46f1))

## 2024.11.1 (2024-06-12)


### Other


* Merge branch &#39;main&#39; of https://github.com/rjdbcm/blastpipe
([`9f9e312`](https://github.com/OZI-Project/blastpipe/commit/9f9e31284d924374118c37f96b503236ac76fe0d))

## 2024.11.0 (2024-06-12)


### 🐛 Fixed Bugs

*  escape template — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`8dc4c37`](https://github.com/OZI-Project/blastpipe/commit/8dc4c379e6517f4fe43a70b54ec5304ca1115932))


### ✨ Implemented Features

* (ozi-templates): add github cleanup workflow template — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`927d2bc`](https://github.com/OZI-Project/blastpipe/commit/927d2bc6975c1573f05c0e0ec264eef72fc0c183))


### Other


* add cleanup template to build
([`9aaeaf6`](https://github.com/OZI-Project/blastpipe/commit/9aaeaf60c4a368a9d677d057633a375c15aca439))

## 2024.10.5 (2024-06-11)


### 🐛 Fixed Bugs

*  fix readme-renderer in meson lint suite. — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`3b8e8fb`](https://github.com/OZI-Project/blastpipe/commit/3b8e8fbba66e7fcad0010a6fe5879aed7b290387))

## 2024.10.4 (2024-06-07)


### ⬆️ Upgraded Dependencies

*  Bump step-security/harden-runner from 2.8.0 to 2.8.1

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.8.0 to 2.8.1.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/f086349bfa2bd1361f7909c78558e816508cdc10...17d0e2bd7d51742c71671bd19fa12bdc9d40a3d6)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`9ac415c`](https://github.com/OZI-Project/blastpipe/commit/9ac415c38969e44b1f9e54449819430d562e2098))


### Other


* Merge pull request #105 from OZI-Project/dependabot/github_actions/step-security/harden-runner-2.8.1

⬆️ Bump step-security/harden-runner from 2.8.0 to 2.8.1
([`79b77af`](https://github.com/OZI-Project/blastpipe/commit/79b77af0638b5752f73f83c020a42a0fb0c42504))

## 2024.10.3 (2024-06-06)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/publish from 0.1.4 to 0.1.5

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.4 to 0.1.5.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/132db35a4d8eaec96886eecc50034f3c3db8bc45...edb7e48d4196153b8dabddb970405495e1ff2092)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`59f26e5`](https://github.com/OZI-Project/blastpipe/commit/59f26e5dd472c95c6a9a31325d84761c47359632))

*  Bump OZI-Project/draft from 0.3.0 to 0.3.1

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.0 to 0.3.1.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/b1b9f3b412ed16a45dfe7c6f60ea8d6fbae97630...f136e6eb55507553aee04e92455cc2dc279583fc)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`9a033c8`](https://github.com/OZI-Project/blastpipe/commit/9a033c8e2da5adb93401b167e294786c3f229004))

*  Bump actions/dependency-review-action from 4.3.2 to 4.3.3

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.3.2 to 4.3.3.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/0c155c5e8556a497adf53f2c18edabf945ed8e70...72eb03d02c7872a771aacd928f3123ac62ad6d3a)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`324fc3e`](https://github.com/OZI-Project/blastpipe/commit/324fc3eed0532fce7645face2a5688cb116cc6d7))


### Other


* Merge pull request #102 from OZI-Project/dependabot/github_actions/OZI-Project/publish-0.1.5

⬆️ Bump OZI-Project/publish from 0.1.4 to 0.1.5
([`46baa54`](https://github.com/OZI-Project/blastpipe/commit/46baa54754689a38c31f407e00c7ec5b2107fb4b))

* Merge pull request #103 from OZI-Project/dependabot/github_actions/OZI-Project/draft-0.3.1

⬆️ Bump OZI-Project/draft from 0.3.0 to 0.3.1
([`0425389`](https://github.com/OZI-Project/blastpipe/commit/0425389f82b28e81cf21aaf5f2431518f0bcaa97))

* Merge pull request #104 from OZI-Project/dependabot/github_actions/actions/dependency-review-action-4.3.3

⬆️ Bump actions/dependency-review-action from 4.3.2 to 4.3.3
([`29912f1`](https://github.com/OZI-Project/blastpipe/commit/29912f1845a87781c738f25944a9b9592110d640))

## 2024.10.2 (2024-06-04)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.25.6 to 3.25.8

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.6 to 3.25.8.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/9fdb3e49720b44c48891d036bb502feb25684276...2e230e8fe0ad3a14a340ad0815ddb96d599d2aff)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`518b056`](https://github.com/OZI-Project/blastpipe/commit/518b056197d92b7ba899389ff11da75cc6d53310))


### Other


* Merge pull request #101 from OZI-Project/dependabot/github_actions/github/codeql-action-3.25.8

⬆️ Bump github/codeql-action from 3.25.6 to 3.25.8
([`a07402e`](https://github.com/OZI-Project/blastpipe/commit/a07402e39d1c119eea126564da068585005e932c))

## 2024.10.1 (2024-05-30)


### 🐛 Fixed Bugs

*  fix incorrect python-dist refs in templates.
([`0ca1343`](https://github.com/OZI-Project/blastpipe/commit/0ca1343aed0d868d1cca1a90039d8250673989b6))

## 2024.10.0 (2024-05-30)


### 🐛 Fixed Bugs

*  fix draft version was pinned statically.
([`3cce3ba`](https://github.com/OZI-Project/blastpipe/commit/3cce3ba7d1658e1a40227718d8c5671876265dd9))


### ✨ Implemented Features

*  OZI-Project/draft@0.3.0 OZI-Project/release@0.6.0 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`36b199e`](https://github.com/OZI-Project/blastpipe/commit/36b199e293d3859e5a0ec465fa8c265127c8c1f5))

## 2024.9.4 (2024-05-29)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/publish from 0.1.3 to 0.1.4

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.3 to 0.1.4.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/f5d14bfb29fd5daa0fd3002a9c57f863e86ddf93...132db35a4d8eaec96886eecc50034f3c3db8bc45)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`bb73cb1`](https://github.com/OZI-Project/blastpipe/commit/bb73cb14981a521e83878cef240fb26b5fca7a57))

*  Bump OZI-Project/draft from 0.2.0 to 0.2.1

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.2.0 to 0.2.1.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/52700faa171c8b44e53834c4878e6cbca430b1d9...914c0f88bb59d105ed0fc061278442565bb6860c)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`b4eb1cd`](https://github.com/OZI-Project/blastpipe/commit/b4eb1cd4c61d0af2cdfe18deadc544f6c5779c8e))


### Other


* Merge pull request #98 from OZI-Project/dependabot/github_actions/OZI-Project/publish-0.1.4

⬆️ Bump OZI-Project/publish from 0.1.3 to 0.1.4
([`de73b76`](https://github.com/OZI-Project/blastpipe/commit/de73b76162ffe81bc0c92110136e9a395931ede8))

* Merge pull request #99 from OZI-Project/dependabot/github_actions/OZI-Project/draft-0.2.1

⬆️ Bump OZI-Project/draft from 0.2.0 to 0.2.1
([`99a1865`](https://github.com/OZI-Project/blastpipe/commit/99a18654932df33cf0019c6371e4b7c227a7a61e))

## 2024.9.3 (2024-05-27)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/checkpoint from 0.3.1 to 0.4.0

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.3.1 to 0.4.0.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/0c54a8e9bbbe5817b8c75a97b4cd6871a64f65f7...64e790c506ba8df435c545f0d4135fbfde23f6a0)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`3dd0525`](https://github.com/OZI-Project/blastpipe/commit/3dd0525e3cac3b53049e6c6768b74883a6fefac0))

*  Bump OZI-Project/publish from 0.1.2 to 0.1.3

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.2 to 0.1.3.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/e0a606616e2ff69a1b564f151f1061601683668f...f5d14bfb29fd5daa0fd3002a9c57f863e86ddf93)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`6ab4af6`](https://github.com/OZI-Project/blastpipe/commit/6ab4af6d5b34b8e6d54f1930cf6491e7fb413824))


### Other


* Merge pull request #96 from OZI-Project/dependabot/github_actions/OZI-Project/checkpoint-0.4.0

⬆️ Bump OZI-Project/checkpoint from 0.3.1 to 0.4.0
([`00b12b3`](https://github.com/OZI-Project/blastpipe/commit/00b12b3ffe60f11ac4b0f64ad635fc541cdb6b0d))

* Merge pull request #97 from OZI-Project/dependabot/github_actions/OZI-Project/publish-0.1.3

⬆️ Bump OZI-Project/publish from 0.1.2 to 0.1.3
([`ec9feb8`](https://github.com/OZI-Project/blastpipe/commit/ec9feb8d5b663efd5f3c146b38f431decf015802))

## 2024.9.2 (2024-05-23)


### 🐛 Fixed Bugs

* 🔧 Add 3.13 support — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`42fc53d`](https://github.com/OZI-Project/blastpipe/commit/42fc53d8887b318bfc088d90d051ad4372a96f41))

## 2024.9.1 (2024-05-22)


### ⬆️ Upgraded Dependencies

*  step-security/harden-runner v2.8.0 in ozi_templates — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`fc957e7`](https://github.com/OZI-Project/blastpipe/commit/fc957e7be34599dda04dd360f5deeba06cd73b60))


### Other


* Merge pull request #95 from OZI-Project/dependabot/github_actions/OZI-Project/release-0.5.10

⬆️ Bump OZI-Project/release from 0.5.9 to 0.5.10
([`addaf32`](https://github.com/OZI-Project/blastpipe/commit/addaf32f12e2e8db585ae6de94d8835bad5e4270))

* 


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`71e7773`](https://github.com/OZI-Project/blastpipe/commit/71e777342ef6edea2d0e340ba0a2b748c96e26ef))

* Merge pull request #94 from OZI-Project/dependabot/github_actions/step-security/harden-runner-2.8.0

⬆️ Bump step-security/harden-runner from 2.7.1 to 2.8.0
([`1b6dcfb`](https://github.com/OZI-Project/blastpipe/commit/1b6dcfb1352cf05a6f4d1b355d82bd92234062ad))

* 


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`3becfb3`](https://github.com/OZI-Project/blastpipe/commit/3becfb3a5e5f32ae56a502d8e460fbe76bea3199))

## 2024.9.0 (2024-05-21)


### ⬆️ Upgraded Dependencies

*  OZI-Project/release 0.5.7 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`3c00b9d`](https://github.com/OZI-Project/blastpipe/commit/3c00b9d29e3aa8ebabcc065544c343ec9cded4d2))

*  OZI-Project/release 0.5.5 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`bbef472`](https://github.com/OZI-Project/blastpipe/commit/bbef4727bebb5d5e97d89fb3d5ba24318d36012b))

*  OZI-Project/release 0.5.4 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`e552edf`](https://github.com/OZI-Project/blastpipe/commit/e552edf11c8938e5b7d259ef3f8d1c152aa01b4c))

*  OZI-Project/release 0.5.3
([`92b9493`](https://github.com/OZI-Project/blastpipe/commit/92b9493e74a8b10aa809cae7e1927214ed9efe5d))

*  OZI-Project/release 0.5.2 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`f5ffdf3`](https://github.com/OZI-Project/blastpipe/commit/f5ffdf32b02ef787d36b46b60dc78e4c29935797))


### 🐛 Fixed Bugs

*  add allow for our endpoint domain — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`145c1fa`](https://github.com/OZI-Project/blastpipe/commit/145c1fa9d11ff28284fb1f5b203a97aa4bd5e49a))

*  Add API endpoint to allowlist in workflow hardener. — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`f4b74a4`](https://github.com/OZI-Project/blastpipe/commit/f4b74a43858719c9200821aa3067b9094aeb380e))

*  patch checkpoint and release. — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`09f65b0`](https://github.com/OZI-Project/blastpipe/commit/09f65b05c347cc2607f029adf1b083b85fbb39a1))

*  allow our API endpoint.
([`f14821c`](https://github.com/OZI-Project/blastpipe/commit/f14821c50637d65ebf199d80669b002178c08502))


### 🔨 Updated Scripts

*  bump OZI-Project/checkpoint 0.3.0

add prerelease checkpoint — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`96ae984`](https://github.com/OZI-Project/blastpipe/commit/96ae984725f659306adcafc502b51dcf061d1949))

*  add prerelease checkpoint
([`e859d10`](https://github.com/OZI-Project/blastpipe/commit/e859d1066274212d3fef019896b975240d3c007b))


### ✨ Implemented Features

*  Update OZI-Project/release 0.5.0

Use the release distribution names rather than version number. — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`896ceef`](https://github.com/OZI-Project/blastpipe/commit/896ceefa68c39e989978b2ea98ebfbefdf2dd000))


### Other


* bump release
([`c196438`](https://github.com/OZI-Project/blastpipe/commit/c196438dc73d2761269fe5107eb69fe71a6a2136))

* Merge branch &#39;main&#39; of https://github.com/rjdbcm/blastpipe
([`9e37da3`](https://github.com/OZI-Project/blastpipe/commit/9e37da3eb8c200f6639b2b13e106dd386fffbc7e))

* add  allow objects.githubusercontent.com:443
([`b405f3e`](https://github.com/OZI-Project/blastpipe/commit/b405f3ecb85b734412f164b964a69b1699f37391))

* Merge branch &#39;main&#39; of https://github.com/rjdbcm/blastpipe
([`505e783`](https://github.com/OZI-Project/blastpipe/commit/505e7830fe7409e129a48ccb7b6b69755c78d3ef))

* fix release
([`c717db0`](https://github.com/OZI-Project/blastpipe/commit/c717db0de25e3cd40990cdde41f17200691cc177))

* Merge branch &#39;main&#39; of https://github.com/rjdbcm/blastpipe
([`0223a1c`](https://github.com/OZI-Project/blastpipe/commit/0223a1cb72bda853198bcf2bc58fa88ca7011dc9))

* release 0.5.6 + draft 0.2.0 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`193b6f9`](https://github.com/OZI-Project/blastpipe/commit/193b6f9ae0299027b3db6d7978b9a6f2022615e1))

* Merge branch &#39;main&#39; of https://github.com/rjdbcm/blastpipe
([`d5b613e`](https://github.com/OZI-Project/blastpipe/commit/d5b613e5298647c776a895beb5abeb5916ec21c0))

* Merge branch &#39;main&#39; of https://github.com/rjdbcm/blastpipe
([`116dd01`](https://github.com/OZI-Project/blastpipe/commit/116dd01683e1f8e813d95f839597fb30770ffe95))

* Merge branch &#39;main&#39; of https://github.com/rjdbcm/blastpipe
([`8a40aa6`](https://github.com/OZI-Project/blastpipe/commit/8a40aa6b67729b4990c6183b02aad5607b567985))

* Merge branch &#39;main&#39; of https://github.com/rjdbcm/blastpipe
([`c7e4a3a`](https://github.com/OZI-Project/blastpipe/commit/c7e4a3a3cc75e05b7454a4772b56a9f63414a0f5))

* skip 3.13 checkpoint
([`d00dd77`](https://github.com/OZI-Project/blastpipe/commit/d00dd77bc5e69996c3401e2804c9e0a398421962))

## 2024.8.1 (2024-05-20)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/publish from 0.1.1 to 0.1.2

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.1 to 0.1.2.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/87aae4bed7ea3ab8b864689945200ecd71ecc29f...e0a606616e2ff69a1b564f151f1061601683668f)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`84f06ec`](https://github.com/OZI-Project/blastpipe/commit/84f06ec34a56eb53451953b37087bab744cf5ed9))

*  Bump OZI-Project/release from 0.4.0 to 0.4.1

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.4.0 to 0.4.1.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/8b5e46e9d8899289f676ca2b432a63fe2faa93f9...033e98adfa7086d1b1273bcc80b0576297e733bd)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`575bfcf`](https://github.com/OZI-Project/blastpipe/commit/575bfcfc9954f7b293b56d73cf48d3058782c093))

*  Bump github/codeql-action from 3.25.5 to 3.25.6

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.5 to 3.25.6.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/b7cec7526559c32f1616476ff32d17ba4c59b2d6...9fdb3e49720b44c48891d036bb502feb25684276)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`15b3fc4`](https://github.com/OZI-Project/blastpipe/commit/15b3fc44f963408323dbe33140fcd5731acecb05))


### Other


* Merge pull request #91 from OZI-Project/dependabot/github_actions/OZI-Project/publish-0.1.2

⬆️ Bump OZI-Project/publish from 0.1.1 to 0.1.2
([`f00695e`](https://github.com/OZI-Project/blastpipe/commit/f00695e664028fe6290fb3e54b6567149daf1b40))

* Merge pull request #92 from OZI-Project/dependabot/github_actions/OZI-Project/release-0.4.1

⬆️ Bump OZI-Project/release from 0.4.0 to 0.4.1
([`aa67aa7`](https://github.com/OZI-Project/blastpipe/commit/aa67aa738451af103e2b9e095e770fcbece5cf60))

* Merge pull request #93 from OZI-Project/dependabot/github_actions/github/codeql-action-3.25.6

⬆️ Bump github/codeql-action from 3.25.5 to 3.25.6
([`51c3263`](https://github.com/OZI-Project/blastpipe/commit/51c32637c11ef174e1c4a71fa73ee2662349531d))

## 2024.8.0 (2024-05-18)


### ⬆️ Upgraded Dependencies

*  OZI-Project/checkpoint 0.2.0 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`51c6cf4`](https://github.com/OZI-Project/blastpipe/commit/51c6cf4a7fc4e53e02e62fed33d42b2bb380c17a))


### ✨ Implemented Features

*  OZI Spec v0.4 and OZI-1.8 changes.
([`66125f1`](https://github.com/OZI-Project/blastpipe/commit/66125f183276f96b96da0684abefd8acf3a6d832))


### Other


* 2024.8
Automatically generated by python-semantic-release
([`b030144`](https://github.com/OZI-Project/blastpipe/commit/b030144f2c68f4833ce528b577446a9b94e68682))

## 2024.7.7 (2024-05-17)


### ⬆️ Upgraded Dependencies

*  Bump actions/checkout from 4.1.5 to 4.1.6

Bumps [actions/checkout](https://github.com/actions/checkout) from 4.1.5 to 4.1.6.
- [Release notes](https://github.com/actions/checkout/releases)
- [Changelog](https://github.com/actions/checkout/blob/main/CHANGELOG.md)
- [Commits](https://github.com/actions/checkout/compare/44c2b7a8a4ea60a981eaca3cf939b5f4305c123b...a5ac7e51b41094c92402da3b24376905380afc29)


updated-dependencies:
- dependency-name: actions/checkout
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`b89106e`](https://github.com/OZI-Project/blastpipe/commit/b89106eaefdd2acdde0d1b623cbfe2e71060bc9d))

*  Bump OZI-Project/draft from 0.1.1 to 0.1.2

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.1.1 to 0.1.2.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/7fb25933b941dc9531abb0809d0be0c79404b351...574ec018b98bb323c079a826b54247c78cc4abac)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`1b9834b`](https://github.com/OZI-Project/blastpipe/commit/1b9834b94e3bd12cace7ad6387203044abc806b4))


### Other


* Merge pull request #88 from OZI-Project/dependabot/github_actions/actions/checkout-4.1.6

⬆️ Bump actions/checkout from 4.1.5 to 4.1.6
([`890344c`](https://github.com/OZI-Project/blastpipe/commit/890344ceb2d57e44449292407b52583630c7cf4b))

* Merge pull request #89 from OZI-Project/dependabot/github_actions/OZI-Project/draft-0.1.2

⬆️ Bump OZI-Project/draft from 0.1.1 to 0.1.2
([`42c32ec`](https://github.com/OZI-Project/blastpipe/commit/42c32ec0d7753a42a790ca6875d64b578af58cc1))

## 2024.7.6 (2024-05-15)


### :lipstick:


* 📝 Update README.rst — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`76e6c55`](https://github.com/OZI-Project/blastpipe/commit/76e6c556e6a77e8f4b30572d3e2c1283f0272eb5))

## 2024.7.5 (2024-05-15)


### 🐛 Fixed Bugs

*  update optional-deps. — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`0fc1b21`](https://github.com/OZI-Project/blastpipe/commit/0fc1b215ebdae8d2a9f6d725607bd1e9e96df9d9))

## 2024.7.4 (2024-05-14)


### 🐛 Fixed Bugs

*  add missing readme-renderer args. — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`4091134`](https://github.com/OZI-Project/blastpipe/commit/4091134c937b45c20b7c72ac4761700d01c558a1))

## 2024.7.3 (2024-05-14)


### 🐛 Fixed Bugs

* ✏️ fix README reference in build template. — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`fdff0ef`](https://github.com/OZI-Project/blastpipe/commit/fdff0eff07d8acc60ded0d0fd2db9c8e7c1f7f40))

## 2024.7.2 (2024-05-14)


### 🐛 Fixed Bugs

* ✏️ Fix README template names. — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`a9da1b2`](https://github.com/OZI-Project/blastpipe/commit/a9da1b2d2745394d9fba53f885f9dd457b1fe08a))

## 2024.7.1 (2024-05-14)


### 🐛 Fixed Bugs

* ✏️ fix README.md template header.
([`9f52201`](https://github.com/OZI-Project/blastpipe/commit/9f5220164ff39e0441122c95e7a672fa3b7ce34f))

## 2024.7.0 (2024-05-14)


### ✨ Implemented Features

*  add spec 0.3 features.

Markdown and plaintext template support. — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`5a63450`](https://github.com/OZI-Project/blastpipe/commit/5a6345037f9f1b3d73ba3105aaec0761f52b27ae))


### Other


* Merge pull request #87 from OZI-Project/feature/spec-0.3

✨ add spec 0.3 features.
([`d567705`](https://github.com/OZI-Project/blastpipe/commit/d567705b8ce00f780d72ce5a6e68766c8328cda2))

## 2024.6.4 (2024-05-13)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/draft from 0.1.0 to 0.1.1

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.1.0 to 0.1.1.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/12b9a4f0d4e25ff5466bf2b0486d11aa4f3bf30d...7fb25933b941dc9531abb0809d0be0c79404b351)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`501ad4c`](https://github.com/OZI-Project/blastpipe/commit/501ad4cd10af6e32cf7d32eee5b9ff7c754d09cb))

*  Bump github/codeql-action from 3.25.4 to 3.25.5

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.4 to 3.25.5.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/ccf74c947955fd1cf117aef6a0e4e66191ef6f61...b7cec7526559c32f1616476ff32d17ba4c59b2d6)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`1707d54`](https://github.com/OZI-Project/blastpipe/commit/1707d54e142d8a4bf93b656b9470db27f442f8ab))


### Other


* Merge pull request #86 from OZI-Project/dependabot/github_actions/OZI-Project/draft-0.1.1

⬆️ Bump OZI-Project/draft from 0.1.0 to 0.1.1
([`0cf0777`](https://github.com/OZI-Project/blastpipe/commit/0cf07778182c0b64a9c11ef84ebce432d9db6493))

* Merge pull request #85 from OZI-Project/dependabot/github_actions/github/codeql-action-3.25.5

⬆️ Bump github/codeql-action from 3.25.4 to 3.25.5
([`766fc5c`](https://github.com/OZI-Project/blastpipe/commit/766fc5cb037da37ab86d11d69719f84c3ed32be0))

## 2024.6.3 (2024-05-10)


### ✏️ Corrected Typos

*  Correct commit_parser_options based on parsing semantic. — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`81d85f0`](https://github.com/OZI-Project/blastpipe/commit/81d85f0aa7dbd0f09ec617943f90e93b65a9d937))

## 2024.6.2 (2024-05-10)


### ✏️ Corrected Typos

*  fix missing comma
([`1a38272`](https://github.com/OZI-Project/blastpipe/commit/1a382721df06a500b9551794fcbf222cff302b5a))

*  add 0.2 specification changes for templates. — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`fe913ba`](https://github.com/OZI-Project/blastpipe/commit/fe913bae55de47a33d2e2ca69636d3ec146c5439))

## 2024.6.1 (2024-05-10)


### ✏️ Corrected Typos

*  Update ozi.yml fix missing 3.10 checkpoint — Eden Rose, MSc &lt;ozi.project@outlook.com&gt;
([`bd46c8b`](https://github.com/OZI-Project/blastpipe/commit/bd46c8b03bec702e0b2a6163347b07000fdda3b8))

## 2024.6.0 (2024-05-10)


### ⬆️ Upgraded Dependencies

*  Bump ossf/scorecard-action from 2.3.1 to 2.3.3

Bumps [ossf/scorecard-action](https://github.com/ossf/scorecard-action) from 2.3.1 to 2.3.3.
- [Release notes](https://github.com/ossf/scorecard-action/releases)
- [Changelog](https://github.com/ossf/scorecard-action/blob/main/RELEASE.md)
- [Commits](https://github.com/ossf/scorecard-action/compare/0864cf19026789058feabb7e87baa5f140aac736...dc50aa9510b46c811795eb24b2f1ba02a914e534)


updated-dependencies:
- dependency-name: ossf/scorecard-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`0cf8d28`](https://github.com/OZI-Project/blastpipe/commit/0cf8d285935bb2ccddd55f986a914efc6c5fcf7f))


### ✏️ Corrected Typos

*  fix release pin — Eden Rose, MSc &lt;ozi.project@outlook.com&gt;
([`ffd1c77`](https://github.com/OZI-Project/blastpipe/commit/ffd1c7727c3a84a8d34bbaaf12012c948f3dbaa5))


### Other


* Update ozi.yml — Eden Rose, MSc &lt;ozi.project@outlook.com&gt;
([`d19756f`](https://github.com/OZI-Project/blastpipe/commit/d19756f7bd1efc0922436375ba79260283972261))

* Merge pull request #83 from OZI-Project/dependabot/github_actions/ossf/scorecard-action-2.3.3

⬆️ Bump ossf/scorecard-action from 2.3.1 to 2.3.3
([`cebe82b`](https://github.com/OZI-Project/blastpipe/commit/cebe82be76da9323151c2796f54a77e99cb12450))

* Merge pull request #84 from OZI-Project/spec-0.2-workflow

✨ add spec 0.2 isolated release drafting.
([`1464321`](https://github.com/OZI-Project/blastpipe/commit/1464321ede5b872764e7131ec95c480de2e4ef8a))

* Merge branch &#39;dependabot/github_actions/ossf/scorecard-action-2.3.3&#39; into spec-0.2-workflow — Eden Rose, MSc &lt;ozi.project@outlook.com&gt;
([`c4e2a03`](https://github.com/OZI-Project/blastpipe/commit/c4e2a03b7f5f6b84a55573795cbcefe1fb1393ad))

## 2024.5.2 (2024-05-10)


### Other


* Merge pull request #82 from OZI-Project/add-ext_modules-feature

✏️ relicense templates to The Unlicense.
([`6c3d0b9`](https://github.com/OZI-Project/blastpipe/commit/6c3d0b9567105e67a9043d78249c9b014ae5bff4))

## 2024.5.1 (2024-05-09)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/checkpoint from 0.1.5 to 0.1.6

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.1.5 to 0.1.6.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/a6290f1edcd89a03dca8d123327e25f0c3bfc91c...1ad9ec15d60558ee3da890634bb8b0406838e17a)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`e7bdbb3`](https://github.com/OZI-Project/blastpipe/commit/e7bdbb3a920660adb5aa2342620c757017cbd7d1))

*  Bump OZI-Project/publish from 0.1.0 to 0.1.1

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.0 to 0.1.1.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/d9173e726b4cbb2ecd631fff0259656737e0dc23...87aae4bed7ea3ab8b864689945200ecd71ecc29f)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`fe59319`](https://github.com/OZI-Project/blastpipe/commit/fe59319fb9d3ef7aeeb02fd1f259e7a0affdb97a))

*  Bump OZI-Project/release from 0.3.0 to 0.3.2

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.3.0 to 0.3.2.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/3067778a8ac4622c1075321b46b7a7333bea64a0...41916dbfb9a8fd0e73da21453fb999796cda9b52)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`db29000`](https://github.com/OZI-Project/blastpipe/commit/db290000300f3bbd5c2dc967f9f254fbe1c402f2))

*  Bump github/codeql-action from 3.25.3 to 3.25.4

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.3 to 3.25.4.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/d39d31e687223d841ef683f52467bd88e9b21c14...ccf74c947955fd1cf117aef6a0e4e66191ef6f61)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`5052d39`](https://github.com/OZI-Project/blastpipe/commit/5052d398ad94cdd7e2d4c2ec77f9f3a546f7cf7c))

*  Bump actions/checkout from 4.1.4 to 4.1.5

Bumps [actions/checkout](https://github.com/actions/checkout) from 4.1.4 to 4.1.5.
- [Release notes](https://github.com/actions/checkout/releases)
- [Changelog](https://github.com/actions/checkout/blob/main/CHANGELOG.md)
- [Commits](https://github.com/actions/checkout/compare/0ad4b8fadaa221de15dcec353f45205ec38ea70b...44c2b7a8a4ea60a981eaca3cf939b5f4305c123b)


updated-dependencies:
- dependency-name: actions/checkout
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`91e2c9b`](https://github.com/OZI-Project/blastpipe/commit/91e2c9b742241dab90e33e8a86b37fff628da1e4))


### Other


* Merge pull request #81 from OZI-Project/dependabot/github_actions/OZI-Project/checkpoint-0.1.6

⬆️ Bump OZI-Project/checkpoint from 0.1.5 to 0.1.6
([`1254b6c`](https://github.com/OZI-Project/blastpipe/commit/1254b6c1d9b042b7c5cf0659ebf56b088ed59230))

* Merge pull request #80 from OZI-Project/dependabot/github_actions/OZI-Project/publish-0.1.1

⬆️ Bump OZI-Project/publish from 0.1.0 to 0.1.1
([`83ee0d9`](https://github.com/OZI-Project/blastpipe/commit/83ee0d91a7f1a1a0fc0dd56299d312dfb1e0d8f3))

* Merge pull request #78 from OZI-Project/dependabot/github_actions/OZI-Project/release-0.3.2

⬆️ Bump OZI-Project/release from 0.3.0 to 0.3.2
([`a5ec912`](https://github.com/OZI-Project/blastpipe/commit/a5ec91239e10962c9e050e77fab55edfe61cb1b4))

* Merge pull request #79 from OZI-Project/dependabot/github_actions/github/codeql-action-3.25.4

⬆️ Bump github/codeql-action from 3.25.3 to 3.25.4
([`be2cdf4`](https://github.com/OZI-Project/blastpipe/commit/be2cdf4ff3c92cd533555d7a0a86ea44c6fe96f1))

* Merge pull request #76 from OZI-Project/dependabot/github_actions/actions/checkout-4.1.5

⬆️ Bump actions/checkout from 4.1.4 to 4.1.5
([`0ebb39c`](https://github.com/OZI-Project/blastpipe/commit/0ebb39c4cdaaa4ee5d0f3d2e684f800fa52dbb96))

## 2024.5.0 (2024-05-07)


### ✏️ Corrected Typos

*  relicense templates to The Unlicense.

Also cleans up metadata — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`809879a`](https://github.com/OZI-Project/blastpipe/commit/809879a8234693a9da688eb3daecf8dcefa1082f))


### ✨ Implemented Features

*  add spec 0.2 isolated release drafting. — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`b8206e7`](https://github.com/OZI-Project/blastpipe/commit/b8206e79ef757b4dba37588a9a8d0709d9937879))

*  Add Cython extension template.

Also adds a check for ``project.enable_cython`` to add a ``build-requires`` and ``meson.project()`` language argument. — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`6b6f1cc`](https://github.com/OZI-Project/blastpipe/commit/6b6f1cc3ad61f8db069e7fdacd43a92f36a43cf3))


### Other


* Merge pull request #77 from OZI-Project/add-ext_modules-feature

✨ Add Cython extension template.
([`edfdaf4`](https://github.com/OZI-Project/blastpipe/commit/edfdaf4f6abc77c43635d2704df356d3ff65f98e))

## 2024.4.7 (2024-05-05)


### 🔨 Updated Scripts

*  skip lint on PyPy builds — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`3cb1933`](https://github.com/OZI-Project/blastpipe/commit/3cb1933b75c55d29df8b3a4e6b8d191758f10537))

## 2024.4.6 (2024-05-05)


### 🐛 Fixed Bugs

*  add pypy ci checkpoint config — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`93a3bb4`](https://github.com/OZI-Project/blastpipe/commit/93a3bb4ea9de4b2a12c8b032a21d513aecc798b2))

## 2024.4.5 (2024-05-05)


### ⚗️


*  direct compile with ninja for checkpoints. — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`5e0f568`](https://github.com/OZI-Project/blastpipe/commit/5e0f5689296919d4eaeb71c6737b5c8554590430))


### ⬆️ Upgraded Dependencies

*  update tox OZI.build pin
([`433f095`](https://github.com/OZI-Project/blastpipe/commit/433f0954060722270a72abc50245864caf27816f))

*  OZI.build&gt;=0.0.15

Also add pypy release test — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`195ac17`](https://github.com/OZI-Project/blastpipe/commit/195ac170f43842e5de8b1946cb824945d86b1029))


### Other


* remove pypy release pattern
([`2cba3de`](https://github.com/OZI-Project/blastpipe/commit/2cba3dea05cb0927d9f3eddc0431fce7710896e0))

## 2024.4.4 (2024-05-04)


### ⬆️ Upgraded Dependencies

*  Bump actions/dependency-review-action from 4.3.1 to 4.3.2

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.3.1 to 4.3.2.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/e58c696e52cac8e62d61cc21fda89565d71505d7...0c155c5e8556a497adf53f2c18edabf945ed8e70)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`a744324`](https://github.com/OZI-Project/blastpipe/commit/a7443244ab62ce8adc1a10036c9948cf532ca9ae))


### Other


* Merge pull request #73 from OZI-Project/dependabot/github_actions/actions/dependency-review-action-4.3.2

⬆️ Bump actions/dependency-review-action from 4.3.1 to 4.3.2
([`44f051e`](https://github.com/OZI-Project/blastpipe/commit/44f051ec21b4f92ea2e2933a0217cad5376f99e3))

## 2024.4.3 (2024-05-04)


### 📌 Pinned Dependencies

*  use head revision.
([`32a2f94`](https://github.com/OZI-Project/blastpipe/commit/32a2f9409ea3ec6df559ca240f60c53ed15fe7bf))

*  OZI version — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`860e5c9`](https://github.com/OZI-Project/blastpipe/commit/860e5c92d9d3d915a2846bf7ce278bcf234f27b5))

*  pin OZI. — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`98b1dab`](https://github.com/OZI-Project/blastpipe/commit/98b1dabd8c80d7b2d2ac125b0d60fa1d6e1e8945))

## 2024.4.2 (2024-05-03)


### 🐛 Fixed Bugs

*  set revision to head — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`b9ea876`](https://github.com/OZI-Project/blastpipe/commit/b9ea876ffcb7dec1ac67456f8d7dbaf005c2c705))


### Other


* Merge branch &#39;main&#39; of https://github.com/rjdbcm/blastpipe
([`13df441`](https://github.com/OZI-Project/blastpipe/commit/13df4416ef454f87bd0660eb68cb3f541152ca4e))

## 2024.4.1 (2024-05-03)


### ⬆️ Upgraded Dependencies

* 🐛 bump OZI.build to 0.0.13 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`ac685cd`](https://github.com/OZI-Project/blastpipe/commit/ac685cd6ad6e03ef47b2e55f8c1ff229b2d5a3a4))


### 📌 Pinned Dependencies

*  OZI-1.3.0 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`6483e7b`](https://github.com/OZI-Project/blastpipe/commit/6483e7bcc536d19e88da446f307a878d07be83b6))

## 2024.4.0 (2024-05-03)


### ⬆️ Upgraded Dependencies

*  update pin version setting.
([`f25169c`](https://github.com/OZI-Project/blastpipe/commit/f25169c0d355bf08137953120ee97e15a5f64e22))


### 🐛 Fixed Bugs

*  bump OZI.build to 0.0.11
([`3a11b6a`](https://github.com/OZI-Project/blastpipe/commit/3a11b6a28eb51b62d3decc2b79d33c479ebade66))

*  Update OZI.build to 0.0.10 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`ce33247`](https://github.com/OZI-Project/blastpipe/commit/ce33247bd24e052e925c3b04cde8924ec2d0f6fe))

*  fix revision pin
([`87cbe1b`](https://github.com/OZI-Project/blastpipe/commit/87cbe1b02fd20530443ede0b1444c1695f38d7b1))


### 🔨 Updated Scripts

*  Change default revision to main in ``ozi.wrap``. — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`e9f34a2`](https://github.com/OZI-Project/blastpipe/commit/e9f34a207a7c1010bc94a6642b452b8e852b0d7e))


### ✨ Implemented Features

* 🐛 Fix for OZI.build integration. — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`ff3c94e`](https://github.com/OZI-Project/blastpipe/commit/ff3c94e265bb1007de97b972667ea6591666f671))

*  Update templates for OZI.build. — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`452358e`](https://github.com/OZI-Project/blastpipe/commit/452358eb4e47a276141e262ed8853a7842596a98))

## 2024.3.0 (2024-05-03)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/release from 0.1.18 to 0.2.5

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.1.18 to 0.2.5.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/7bbceab384cd0290577dec4b4fb04eed3c07b926...26edb1dd060fbfe54494fb6c17aed8afc776a9f2)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`a670efa`](https://github.com/OZI-Project/blastpipe/commit/a670efa0bedbcfff4775d73481218b71226fbbb4))


### ✨ Implemented Features

*  Update pyproject.toml for OZI.build switch — Eden Rose, MSc &lt;ozi.project@outlook.com&gt;
([`4165e7d`](https://github.com/OZI-Project/blastpipe/commit/4165e7da1d873c55237287e166f3c7e1d00d687c))


### Other


* Update pyproject.toml - fix key name typo — Eden Rose, MSc &lt;ozi.project@outlook.com&gt;
([`137b11d`](https://github.com/OZI-Project/blastpipe/commit/137b11df6698189b7f05cf51125ec29bfb46fa33))

* Merge pull request #75 from OZI-Project/dependabot/github_actions/OZI-Project/release-0.2.5

⬆️ Bump OZI-Project/release from 0.1.18 to 0.2.5
([`3d06065`](https://github.com/OZI-Project/blastpipe/commit/3d06065120a1a1d6c24377335fef4c2384fd5ab0))

## 2024.2.10 (2024-04-30)


### ⬆️ Upgraded Dependencies

*  Bump step-security/harden-runner from 2.7.0 to 2.7.1

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.7.0 to 2.7.1.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/63c24ba6bd7ba022e95695ff85de572c04a18142...a4aa98b93cab29d9b1101a6143fb8bce00e2eac4)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`f02635b`](https://github.com/OZI-Project/blastpipe/commit/f02635b0ef614f3ad1b041da8ce561b6678cb758))

*  Bump actions/dependency-review-action from 4.2.5 to 4.3.1

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.2.5 to 4.3.1.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/5bbc3ba658137598168acb2ab73b21c432dd411b...e58c696e52cac8e62d61cc21fda89565d71505d7)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`3a6415a`](https://github.com/OZI-Project/blastpipe/commit/3a6415ac065023aa55c84ac461154f9a8ec32bff))


### Other


* Merge pull request #72 from OZI-Project/dependabot/github_actions/actions/dependency-review-action-4.3.1

⬆️ Bump actions/dependency-review-action from 4.2.5 to 4.3.1
([`ee8d2c6`](https://github.com/OZI-Project/blastpipe/commit/ee8d2c620ac3154c4ffbb1fab821a6c8a0a3273d))

* Merge pull request #71 from OZI-Project/dependabot/github_actions/step-security/harden-runner-2.7.1

⬆️ Bump step-security/harden-runner from 2.7.0 to 2.7.1
([`adf8ffb`](https://github.com/OZI-Project/blastpipe/commit/adf8ffbf2b0379547bc064645067a0f21da1ce90))

## 2024.2.9 (2024-04-28)


### 🔨 Updated Configuration

*  Update status to Alpha

Also fix download-url — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`734c230`](https://github.com/OZI-Project/blastpipe/commit/734c23045be5e063ee045ef9f706c1d91a025434))

## 2024.2.8 (2024-04-28)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/release to 0.1.18 — Eden Rose, MSc &lt;ozi.project@outlook.com&gt;
([`5f6e3e8`](https://github.com/OZI-Project/blastpipe/commit/5f6e3e8de7a004ce3709369ca7b9b1431ac36b08))


### 🐛 Fixed Bugs

*  Update ozi.wrap

fix ``ozi.wrap`` must pin to head no matter what for setuptools-scm. — Eden Rose, MSc &lt;ozi.project@outlook.com&gt;
([`d3acaa7`](https://github.com/OZI-Project/blastpipe/commit/d3acaa78d10903e5bf67edb671e658ba6a838d62))

*  Update ozi.wrap — Eden Rose, MSc &lt;ozi.project@outlook.com&gt;
([`9385846`](https://github.com/OZI-Project/blastpipe/commit/93858463eee1040ec9e91dec0e78967ff42769cc))


### 🔨 Updated Scripts

*  Update ``ozi.wrap``  template and pin repo ``ozi.wrap`` — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`11cc643`](https://github.com/OZI-Project/blastpipe/commit/11cc6431b59bc741989f137670cfad18a44035e3))


### Other


* Merge pull request #70 from OZI-Project/rjdbcm-patch-1

🐛 Update ozi.wrap
([`16209b5`](https://github.com/OZI-Project/blastpipe/commit/16209b586bedac47b6dc8cb23e17c041b88e8e5d))

* Update project.ozi.wrap.j2 — Eden Rose, MSc &lt;ozi.project@outlook.com&gt;
([`b9cad60`](https://github.com/OZI-Project/blastpipe/commit/b9cad60a15a7df575e222c916ec7f7c0bb81b4fd))

## 2024.2.7 (2024-04-28)


### 🔥 Deleted Code or Files

*  remove extra folders.
([`3c94f8c`](https://github.com/OZI-Project/blastpipe/commit/3c94f8c23a0c9f35a571a9b30fabc09562ad1836))

## 2024.2.6 (2024-04-28)


### 🐛 Fixed Bugs

*  Add missing type stubfiles for ozi_templates — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`5382fff`](https://github.com/OZI-Project/blastpipe/commit/5382fff931d6e01536c344a486d9521f35989b65))

## 2024.2.5 (2024-04-28)


### 🐛 Fixed Bugs

*  fix next_minor filter typo. — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`404c645`](https://github.com/OZI-Project/blastpipe/commit/404c6454186915e20b2a2e4b4756f09e507cf30b))

## 2024.2.4 (2024-04-28)


### 🐛 Fixed Bugs

*  Load jinja2 env from blastpipe package. — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`9e34d11`](https://github.com/OZI-Project/blastpipe/commit/9e34d11ab58b2509a8cc9fdf80bc746c62bc8cd1))

## 2024.2.3 (2024-04-27)


### Other


* Merge branch &#39;main&#39; of https://github.com/rjdbcm/blastpipe
([`7f23039`](https://github.com/OZI-Project/blastpipe/commit/7f23039c89bb4d7ebb117a9d20a69f6acaddd970))

## 2024.2.2 (2024-04-27)


### 🐛 Fixed Bugs

*  fix ozi_templates install location.
([`fbd88e4`](https://github.com/OZI-Project/blastpipe/commit/fbd88e4cf80fa32e07e081e0d04e38d3e8359728))

* ✏️ fix templates subdirectory names. — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`25e4344`](https://github.com/OZI-Project/blastpipe/commit/25e434404252686797a917689ff9a8c64cad01d3))

## 2024.2.1 (2024-04-27)


### ✏️ Corrected Typos

*  add Provides-Dist: ozi_templates. — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`79170e0`](https://github.com/OZI-Project/blastpipe/commit/79170e0800512061f77cf9d868b4a7caa2bb4936))

## 2024.2.0 (2024-04-27)


### ➕ Added Dependencies

*  add deps jinja2, requests, types-requests. — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`2d566c8`](https://github.com/OZI-Project/blastpipe/commit/2d566c835be404bb95ed465d680416c5adda2575))


### ✏️ Corrected Typos

*  fix missing source children.
([`0574d2f`](https://github.com/OZI-Project/blastpipe/commit/0574d2f0ac75fc6ddbf18553fb8ed30a2d52f66c))


### ✨ Implemented Features

*  add ozi_templates subdir. — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`08869d3`](https://github.com/OZI-Project/blastpipe/commit/08869d31b561c5eabe445548cd84c7f8391d14f8))


### Other


* 🚨 run isort — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`d0ade4a`](https://github.com/OZI-Project/blastpipe/commit/d0ade4a18dfa0429e6f38771278d828319e33b74))

## 2024.1.3 (2024-04-26)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.25.2 to 3.25.3

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.2 to 3.25.3.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/8f596b4ae3cb3c588a5c46780b86dd53fef16c52...d39d31e687223d841ef683f52467bd88e9b21c14)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`9ba3bcb`](https://github.com/OZI-Project/blastpipe/commit/9ba3bcbbafb32db7b5d292fef20f80b9b787209c))


### Other


* Merge pull request #69 from OZI-Project/dependabot/github_actions/github/codeql-action-3.25.3

⬆️ Bump github/codeql-action from 3.25.2 to 3.25.3
([`a69420e`](https://github.com/OZI-Project/blastpipe/commit/a69420eb4fd8cfb47649fe7be0a9ddea0ddc2b5b))

## 2024.1.2 (2024-04-24)


### ⬆️ Upgraded Dependencies

*  Bump actions/checkout from 4.1.3 to 4.1.4

Bumps [actions/checkout](https://github.com/actions/checkout) from 4.1.3 to 4.1.4.
- [Release notes](https://github.com/actions/checkout/releases)
- [Changelog](https://github.com/actions/checkout/blob/main/CHANGELOG.md)
- [Commits](https://github.com/actions/checkout/compare/1d96c772d19495a3b5c517cd2bc0cb401ea0529f...0ad4b8fadaa221de15dcec353f45205ec38ea70b)


updated-dependencies:
- dependency-name: actions/checkout
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`a95ff85`](https://github.com/OZI-Project/blastpipe/commit/a95ff85ae70d343f016816f22fe13e2c43d7ff31))

*  Bump OZI-Project/release from 0.1.16 to 0.1.17

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.1.16 to 0.1.17.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/cde80205350cc9bd7c00c042b788136b36bd1828...ceffb3c8beef212a5abaffeac486d67fb247381b)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`7df5ad2`](https://github.com/OZI-Project/blastpipe/commit/7df5ad2571d988b0bdadfc972369acc3a13a30eb))


### Other


* Merge pull request #68 from OZI-Project/dependabot/github_actions/actions/checkout-4.1.4

⬆️ Bump actions/checkout from 4.1.3 to 4.1.4
([`5a25586`](https://github.com/OZI-Project/blastpipe/commit/5a2558679c54dcf08c21d555c39bc618138d447c))

* Merge pull request #67 from OZI-Project/dependabot/github_actions/OZI-Project/release-0.1.17

⬆️ Bump OZI-Project/release from 0.1.16 to 0.1.17
([`15db134`](https://github.com/OZI-Project/blastpipe/commit/15db13448d1118d36dfde5fb66bc6a855f705009))

## 2024.1.1 (2024-04-23)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.25.1 to 3.25.2

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.1 to 3.25.2.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/c7f9125735019aa87cfc361530512d50ea439c71...8f596b4ae3cb3c588a5c46780b86dd53fef16c52)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`e119b2e`](https://github.com/OZI-Project/blastpipe/commit/e119b2e997ad0e70068fd99ea5dc72fcb2f9dced))

*  Bump actions/upload-artifact from 4.3.2 to 4.3.3

Bumps [actions/upload-artifact](https://github.com/actions/upload-artifact) from 4.3.2 to 4.3.3.
- [Release notes](https://github.com/actions/upload-artifact/releases)
- [Commits](https://github.com/actions/upload-artifact/compare/1746f4ab65b179e0ea60a494b83293b640dd5bba...65462800fd760344b1a7b4382951275a0abb4808)


updated-dependencies:
- dependency-name: actions/upload-artifact
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`df59855`](https://github.com/OZI-Project/blastpipe/commit/df59855b192e4c465ac1e452539bb1a1ea44c54f))


### Other


* Merge pull request #64 from OZI-Project/dependabot/github_actions/github/codeql-action-3.25.2

⬆️ Bump github/codeql-action from 3.25.1 to 3.25.2
([`255087f`](https://github.com/OZI-Project/blastpipe/commit/255087fafe7964594fa485f2b046ae527560a62c))

* Merge pull request #65 from OZI-Project/dependabot/github_actions/actions/upload-artifact-4.3.3

⬆️ Bump actions/upload-artifact from 4.3.2 to 4.3.3
([`d2f54ab`](https://github.com/OZI-Project/blastpipe/commit/d2f54ab7ed2f5a37d2b432fbd2f6fbf1805d3e3d))

## 2024.1.0 (2024-04-23)


### ⬆️ Upgraded Dependencies

*  Bump slsa-framework/slsa-github-generator

Bumps [slsa-framework/slsa-github-generator](https://github.com/slsa-framework/slsa-github-generator) from 1.10.0 to 2.0.0.
- [Release notes](https://github.com/slsa-framework/slsa-github-generator/releases)
- [Changelog](https://github.com/slsa-framework/slsa-github-generator/blob/main/CHANGELOG.md)
- [Commits](https://github.com/slsa-framework/slsa-github-generator/compare/v1.10.0...v2.0.0)


updated-dependencies:
- dependency-name: slsa-framework/slsa-github-generator
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] &lt;support@github.com&gt;
([`98b3f63`](https://github.com/OZI-Project/blastpipe/commit/98b3f63da24998c356d35d2ffb83db1ab5046995))


### ✨ Implemented Features

*  Merge pull request #66 from OZI-Project/dependabot/github_actions/slsa-framework/slsa-github-generator-2.0.0

⬆️ Bump slsa-framework/slsa-github-generator from 1.10.0 to 2.0.0
([`ee91082`](https://github.com/OZI-Project/blastpipe/commit/ee91082a5858f6b9b9b545a683a4977073466489))

## 2024.0.9 (2024-04-22)


### ⬆️ Upgraded Dependencies

*  Merge pull request #63 from OZI-Project/dependabot/github_actions/OZI-Project/checkpoint-0.1.5

⬆️ Bump OZI-Project/checkpoint from 0.1.4 to 0.1.5
([`98bf23f`](https://github.com/OZI-Project/blastpipe/commit/98bf23fd0fb0da343c75239a65790209922c7f4d))

*  Bump OZI-Project/checkpoint from 0.1.4 to 0.1.5

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.1.4 to 0.1.5.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/8b7d897024b918d4bb4d44bbaec23a22f357182e...a6290f1edcd89a03dca8d123327e25f0c3bfc91c)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`639e7d9`](https://github.com/OZI-Project/blastpipe/commit/639e7d9a186eef91cd4153ab325e1f39106f2175))

*  Bump OZI-Project/release from 0.1.15 to 0.1.16

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.1.15 to 0.1.16.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/f0e0a8b837c2d247b920fbc1997a8d3247b14455...cde80205350cc9bd7c00c042b788136b36bd1828)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`7a52969`](https://github.com/OZI-Project/blastpipe/commit/7a529697cddd85af9f4bb56f5464a1ac0861ae24))


### 🐛 Fixed Bugs

*  Remove subproject folder.
([`dc9f63c`](https://github.com/OZI-Project/blastpipe/commit/dc9f63c355a59a6f607ea43baafb9534d90c65f0))


### Other


* Merge pull request #62 from OZI-Project/dependabot/github_actions/OZI-Project/release-0.1.16

⬆️ Bump OZI-Project/release from 0.1.15 to 0.1.16
([`18a47f7`](https://github.com/OZI-Project/blastpipe/commit/18a47f754675b2353a32fe05b833061444b86050))

## 2024.0.8 (2024-04-22)


### 🔨 Updated Scripts

*  Update requirements.in renderer.
([`843495c`](https://github.com/OZI-Project/blastpipe/commit/843495cbe3bb90df5e7d27b300a05396d0d592de))


### ✏️ Corrected Typos

*  Fix escapes.
([`3baf207`](https://github.com/OZI-Project/blastpipe/commit/3baf207814d7540558d22bbca0ee07bd5969b590))

## 2024.0.7 (2024-04-22)


### 🐛 Fixed Bugs

*  fix requirements rendering.
([`81f3fa4`](https://github.com/OZI-Project/blastpipe/commit/81f3fa4a211d68cc46660714e047be9c818992a3))

## 2024.0.6 (2024-04-22)


### 🐛 Fixed Bugs

*  Fix minor rendering issues with requirements. — rjdbcm &lt;rjdbcm@mail.umkc.edu&gt;
([`2143ed6`](https://github.com/OZI-Project/blastpipe/commit/2143ed6f989eb7c405464d014b0e5a1339c22e93))

## 2024.0.5 (2024-04-21)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/release from 0.1.14 to 0.1.15

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.1.14 to 0.1.15.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/945b312031019d0d85c5674721327f894131d898...f0e0a8b837c2d247b920fbc1997a8d3247b14455)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`6528401`](https://github.com/OZI-Project/blastpipe/commit/6528401f75d5f68228734c2787d43c9c439aa884))

*  Bump OZI-Project/checkpoint from 0.1.3 to 0.1.4

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.1.3 to 0.1.4.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/91c27e2c333d718d7b87992e19511ff5b00cd16e...8b7d897024b918d4bb4d44bbaec23a22f357182e)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`f573e1e`](https://github.com/OZI-Project/blastpipe/commit/f573e1e75dbfe0cd18fab98e51c2e44b66188257))

*  Bump actions/checkout from 4.1.1 to 4.1.3

Bumps [actions/checkout](https://github.com/actions/checkout) from 4.1.1 to 4.1.3.
- [Release notes](https://github.com/actions/checkout/releases)
- [Changelog](https://github.com/actions/checkout/blob/main/CHANGELOG.md)
- [Commits](https://github.com/actions/checkout/compare/b4ffde65f46336ab88eb53be808477a3936bae11...1d96c772d19495a3b5c517cd2bc0cb401ea0529f)


updated-dependencies:
- dependency-name: actions/checkout
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`a2f8815`](https://github.com/OZI-Project/blastpipe/commit/a2f88158906517d20dacc8335282408e6d798edf))

*  Bump actions/upload-artifact from 4.3.1 to 4.3.2

Bumps [actions/upload-artifact](https://github.com/actions/upload-artifact) from 4.3.1 to 4.3.2.
- [Release notes](https://github.com/actions/upload-artifact/releases)
- [Commits](https://github.com/actions/upload-artifact/compare/5d5d22a31266ced268874388b861e4b58bb5c2f3...1746f4ab65b179e0ea60a494b83293b640dd5bba)


updated-dependencies:
- dependency-name: actions/upload-artifact
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`d0f9d7a`](https://github.com/OZI-Project/blastpipe/commit/d0f9d7a79a8699f017dc9861f5b696b84a502b08))

*  Bump github/codeql-action from 3.24.10 to 3.25.1

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.24.10 to 3.25.1.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/4355270be187e1b672a7a1c7c7bae5afdc1ab94a...c7f9125735019aa87cfc361530512d50ea439c71)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`fbe5c3b`](https://github.com/OZI-Project/blastpipe/commit/fbe5c3bac753b872c21c837a3085170534bc6b35))


### 📌 Pinned Dependencies

*  Merge pull request #57 from OZI-Project/dependabot/github_actions/OZI-Project/release-0.1.15

⬆️ Bump OZI-Project/release from 0.1.14 to 0.1.15
([`d809c35`](https://github.com/OZI-Project/blastpipe/commit/d809c3577aa3a0f0160bf682a9fcf6a03b5392cf))

*  Merge pull request #58 from OZI-Project/dependabot/github_actions/OZI-Project/checkpoint-0.1.4

⬆️ Bump OZI-Project/checkpoint from 0.1.3 to 0.1.4
([`b04d131`](https://github.com/OZI-Project/blastpipe/commit/b04d1312f8e331c16bef78ef1f53ed3b2f4aa978))


### Other


* Merge pull request #61 from OZI-Project/dependabot/github_actions/actions/checkout-4.1.3

⬆️ Bump actions/checkout from 4.1.1 to 4.1.3
([`1658a31`](https://github.com/OZI-Project/blastpipe/commit/1658a3150da171997cebf378cf33c1b1f067cab7))

* Merge pull request #60 from OZI-Project/dependabot/github_actions/actions/upload-artifact-4.3.2

⬆️ Bump actions/upload-artifact from 4.3.1 to 4.3.2
([`4f99092`](https://github.com/OZI-Project/blastpipe/commit/4f99092b91a88b9066417ab393b07a5cca79101d))

* Merge pull request #59 from OZI-Project/dependabot/github_actions/github/codeql-action-3.25.1

⬆️ Bump github/codeql-action from 3.24.10 to 3.25.1
([`f381c15`](https://github.com/OZI-Project/blastpipe/commit/f381c15a9d1efa16d441fabaaca0db3963262cfb))

## 2024.0.4 (2024-04-13)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/release from 0.1.13 to 0.1.14

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.1.13 to 0.1.14.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/9a404fb06ef2b5c1634518720f8cdafa41539f77...945b312031019d0d85c5674721327f894131d898)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`1b019b0`](https://github.com/OZI-Project/blastpipe/commit/1b019b04ecfaf30b25a05d9c092ee213a10a0fd5))

*  Bump actions/dependency-review-action from 4.1.3 to 4.2.5

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.1.3 to 4.2.5.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/9129d7d40b8c12c1ed0f60400d00c92d437adcce...5bbc3ba658137598168acb2ab73b21c432dd411b)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`4ae3417`](https://github.com/OZI-Project/blastpipe/commit/4ae34177e2cdc72d9333e924c0e3d31d838d5f9f))

*  Bump github/codeql-action from 3.24.6 to 3.24.10

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.24.6 to 3.24.10.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/8a470fddafa5cbb6266ee11b37ef4d8aae19c571...4355270be187e1b672a7a1c7c7bae5afdc1ab94a)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`d8e7924`](https://github.com/OZI-Project/blastpipe/commit/d8e7924033adcf052e320a2a5e8057833616d53c))

*  Bump actions/upload-artifact from 3.1.3 to 4.3.1

Bumps [actions/upload-artifact](https://github.com/actions/upload-artifact) from 3.1.3 to 4.3.1.
- [Release notes](https://github.com/actions/upload-artifact/releases)
- [Commits](https://github.com/actions/upload-artifact/compare/a8a3f3ad30e3422c9c7b888a15615d19a852ae32...5d5d22a31266ced268874388b861e4b58bb5c2f3)


updated-dependencies:
- dependency-name: actions/upload-artifact
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] &lt;support@github.com&gt;
([`0f33c02`](https://github.com/OZI-Project/blastpipe/commit/0f33c02f27db5a22221b8cd106a214f5b47be0e0))


### 🔨 Updated Scripts

*  bump to lastest OZI.
([`912190a`](https://github.com/OZI-Project/blastpipe/commit/912190ae91ffc5645f00396b76e5e3adab643228))


### ✏️ Corrected Typos

*  Remove unused option variables.
([`71e885f`](https://github.com/OZI-Project/blastpipe/commit/71e885fc0a179846bc02034430beabbd68068992))

*  fix missing envs.
([`b59bc1c`](https://github.com/OZI-Project/blastpipe/commit/b59bc1ca1f3db7ad58858c0ccf8af9e586a1b574))


### Other


* Merge pull request #55 from OZI-Project/dependabot/github_actions/OZI-Project/release-0.1.14

⬆️ Bump OZI-Project/release from 0.1.13 to 0.1.14
([`d4871e4`](https://github.com/OZI-Project/blastpipe/commit/d4871e4fe9345716add535a6755dace925dd5230))

* 🚨 Fix quoted type annotations. — rjdbcm &lt;rjdbcm@mail.umkc.edu&gt;
([`988f9f2`](https://github.com/OZI-Project/blastpipe/commit/988f9f2b8697ce6569b456ebf1343b952d4fdb0c))

* Merge pull request #50 from OZI-Project/dependabot/github_actions/actions/dependency-review-action-4.2.5

⬆️ Bump actions/dependency-review-action from 4.1.3 to 4.2.5
([`d3113fe`](https://github.com/OZI-Project/blastpipe/commit/d3113fe1200a1c6bb7822d96351e1820a18a56f8))

* Merge pull request #54 from OZI-Project/dependabot/github_actions/github/codeql-action-3.24.10

⬆️ Bump github/codeql-action from 3.24.6 to 3.24.10
([`e34440b`](https://github.com/OZI-Project/blastpipe/commit/e34440bb02c1e4750e0acadf2d1fa76f9ae2cf82))

* Merge pull request #52 from OZI-Project/dependabot/github_actions/actions/upload-artifact-4.3.1

⬆️ Bump actions/upload-artifact from 3.1.3 to 4.3.1
([`389ac50`](https://github.com/OZI-Project/blastpipe/commit/389ac505d22f1a893e3e4423ee8fee49706739aa))

## 2024.0.3 (2024-04-04)


### 🔨 Updated Scripts

*  Add install-subprojects option. — rjdbcm &lt;rjdbcm@mail.umkc.edu&gt;
([`af8f951`](https://github.com/OZI-Project/blastpipe/commit/af8f9519a11ed5efd9a86fc6089afb543688a46e))


### ✏️ Corrected Typos

*  remove subproject folder. — rjdbcm &lt;rjdbcm@mail.umkc.edu&gt;
([`727b7d0`](https://github.com/OZI-Project/blastpipe/commit/727b7d0ad55627334ab0f2a919e6d1cc45a24652))

## 2024.0.2 (2024-04-03)


### 🔨 Updated Scripts

*  Don&#39;t bootstrap OZI if blastpipe is a subproject (for now). — rjdbcm &lt;rjdbcm@mail.umkc.edu&gt;
([`0068204`](https://github.com/OZI-Project/blastpipe/commit/006820441f7ac3be090ac02a87fbad2ff0e4bf01))


### ✏️ Corrected Typos

*  fix typo
([`95701bf`](https://github.com/OZI-Project/blastpipe/commit/95701bf17c756a9ee6f72063aad06c9c7286a091))


### Other


*  Remove folder.
([`117e75b`](https://github.com/OZI-Project/blastpipe/commit/117e75b5ba7c4687f4c1fa9dc1bda3972c1e53a9))

## 2024.0.1 (2024-04-03)


### 🔨 Updated Scripts

*  Don&#39;t install when run as subproject. — rjdbcm &lt;rjdbcm@mail.umkc.edu&gt;
([`1973353`](https://github.com/OZI-Project/blastpipe/commit/1973353f4b76ba65b03f6833ca8982ba3347c880))


### Other


* Merge branch &#39;main&#39; of https://github.com/rjdbcm/blastpipe
([`5f143a2`](https://github.com/OZI-Project/blastpipe/commit/5f143a25d5cbf414a77406df336ea14002232a9c))

* Don&#39;t install when run as subproject.
([`a5dfcbc`](https://github.com/OZI-Project/blastpipe/commit/a5dfcbc7ced9f710b01285b704cc4a54538416ec))

## 2024.0.0 (2024-04-03)


### ⬆️ Upgraded Dependencies

*  Bump pypa/gh-action-pypi-publish from 1.8.12 to 1.8.14

Bumps [pypa/gh-action-pypi-publish](https://github.com/pypa/gh-action-pypi-publish) from 1.8.12 to 1.8.14.
- [Release notes](https://github.com/pypa/gh-action-pypi-publish/releases)
- [Commits](https://github.com/pypa/gh-action-pypi-publish/compare/e53eb8b103ffcb59469888563dc324e3c8ba6f06...81e9d935c883d0b210363ab89cf05f3894778450)


updated-dependencies:
- dependency-name: pypa/gh-action-pypi-publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`aed0b73`](https://github.com/OZI-Project/blastpipe/commit/aed0b7365066b3a964ea7619674ac26cc4b51851))

*  Bump actions/download-artifact from 4.1.3 to 4.1.4

Bumps [actions/download-artifact](https://github.com/actions/download-artifact) from 4.1.3 to 4.1.4.
- [Release notes](https://github.com/actions/download-artifact/releases)
- [Commits](https://github.com/actions/download-artifact/compare/87c55149d96e628cc2ef7e6fc2aab372015aec85...c850b930e6ba138125429b7e5c93fc707a7f8427)


updated-dependencies:
- dependency-name: actions/download-artifact
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`c7edd4d`](https://github.com/OZI-Project/blastpipe/commit/c7edd4d6b772bff93e4392cf9645b6af852b3e7d))

*  Bump github/codeql-action from 3.24.5 to 3.24.6

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.24.5 to 3.24.6.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/47b3d888fe66b639e431abf22ebca059152f1eea...8a470fddafa5cbb6266ee11b37ef4d8aae19c571)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`c3a163b`](https://github.com/OZI-Project/blastpipe/commit/c3a163b738989ef5c955d70d409f63e7ad97182d))

*  Bump python-semantic-release/python-semantic-release

Bumps [python-semantic-release/python-semantic-release](https://github.com/python-semantic-release/python-semantic-release) from 9.1.0 to 9.1.1.
- [Release notes](https://github.com/python-semantic-release/python-semantic-release/releases)
- [Changelog](https://github.com/python-semantic-release/python-semantic-release/blob/master/CHANGELOG.md)
- [Commits](https://github.com/python-semantic-release/python-semantic-release/compare/82bfcd3ba619ce6bda0eb79b903be48d3ac5ff2c...c82bd673c30da94a02e039963c8c4c8a51758096)


updated-dependencies:
- dependency-name: python-semantic-release/python-semantic-release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`d75226c`](https://github.com/OZI-Project/blastpipe/commit/d75226c31a7299338e9563a00253336c440b14f8))

*  Bump actions/download-artifact from 4.1.2 to 4.1.3

Bumps [actions/download-artifact](https://github.com/actions/download-artifact) from 4.1.2 to 4.1.3.
- [Release notes](https://github.com/actions/download-artifact/releases)
- [Commits](https://github.com/actions/download-artifact/compare/eaceaf801fd36c7dee90939fad912460b18a1ffe...87c55149d96e628cc2ef7e6fc2aab372015aec85)


updated-dependencies:
- dependency-name: actions/download-artifact
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`819b17f`](https://github.com/OZI-Project/blastpipe/commit/819b17f0502e486882a85c2b89859d64a2e36e0c))

*  Bump pypa/gh-action-pypi-publish from 1.8.11 to 1.8.12

Bumps [pypa/gh-action-pypi-publish](https://github.com/pypa/gh-action-pypi-publish) from 1.8.11 to 1.8.12.
- [Release notes](https://github.com/pypa/gh-action-pypi-publish/releases)
- [Commits](https://github.com/pypa/gh-action-pypi-publish/compare/2f6f737ca5f74c637829c0f5c3acd0e29ea5e8bf...e53eb8b103ffcb59469888563dc324e3c8ba6f06)


updated-dependencies:
- dependency-name: pypa/gh-action-pypi-publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`0c4153b`](https://github.com/OZI-Project/blastpipe/commit/0c4153bb89a9f265996597512c0aa06e837574c7))

*  Bump python-semantic-release/python-semantic-release

Bumps [python-semantic-release/python-semantic-release](https://github.com/python-semantic-release/python-semantic-release) from 8.7.2 to 9.1.0.
- [Release notes](https://github.com/python-semantic-release/python-semantic-release/releases)
- [Changelog](https://github.com/python-semantic-release/python-semantic-release/blob/master/CHANGELOG.md)
- [Commits](https://github.com/python-semantic-release/python-semantic-release/compare/1d2bbdf23aab816cd9d6e26f537b5cec9e39dede...82bfcd3ba619ce6bda0eb79b903be48d3ac5ff2c)


updated-dependencies:
- dependency-name: python-semantic-release/python-semantic-release
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] &lt;support@github.com&gt;
([`c728350`](https://github.com/OZI-Project/blastpipe/commit/c728350e26a625a44ada226c9e8bf3978e2be8ff))

*  Bump actions/download-artifact from 4.1.1 to 4.1.2

Bumps [actions/download-artifact](https://github.com/actions/download-artifact) from 4.1.1 to 4.1.2.
- [Release notes](https://github.com/actions/download-artifact/releases)
- [Commits](https://github.com/actions/download-artifact/compare/6b208ae046db98c579e8a3aa621ab581ff575935...eaceaf801fd36c7dee90939fad912460b18a1ffe)


updated-dependencies:
- dependency-name: actions/download-artifact
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`da484d7`](https://github.com/OZI-Project/blastpipe/commit/da484d7786e0f6bbecedcab6a304a4d282b98b2a))

*  Bump step-security/harden-runner from 2.6.1 to 2.7.0

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.6.1 to 2.7.0.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/eb238b55efaa70779f274895e782ed17c84f2895...63c24ba6bd7ba022e95695ff85de572c04a18142)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`137811f`](https://github.com/OZI-Project/blastpipe/commit/137811f8b6f61d2d9aaac1f3135e1b391fad05ec))

*  Bump actions/dependency-review-action from 4.0.0 to 4.1.3

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.0.0 to 4.1.3.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/4901385134134e04cec5fbe5ddfe3b2c5bd5d976...9129d7d40b8c12c1ed0f60400d00c92d437adcce)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`92e27c0`](https://github.com/OZI-Project/blastpipe/commit/92e27c0ef9baa6b8984309612d41933c93bab9ff))

*  Bump github/codeql-action from 3.23.1 to 3.24.5

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.23.1 to 3.24.5.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/0b21cf2492b6b02c465a3e5d7c473717ad7721ba...47b3d888fe66b639e431abf22ebca059152f1eea)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`8ed4579`](https://github.com/OZI-Project/blastpipe/commit/8ed4579e68ca0a8d2cb49c626896d3c97485f79d))


### 💥


*  Release 2024 — rjdbcm &lt;rjdbcm@mail.umkc.edu&gt;
([`3297787`](https://github.com/OZI-Project/blastpipe/commit/329778729b6de2bce6e6048fc655647ab656718a))


### 🐛 Fixed Bugs

* Fix ozi invocation.
([`02d0f24`](https://github.com/OZI-Project/blastpipe/commit/02d0f249b61a02e95b540b633505df980f240195))

* Fix meson_version included option string.
([`79b9bb7`](https://github.com/OZI-Project/blastpipe/commit/79b9bb716c9593fb7d7da65112692e7697fe0793))

* Fix python_version quoting in tox config as well.
([`f22f738`](https://github.com/OZI-Project/blastpipe/commit/f22f738ceaea1163255f99e4c0d92434e9cae690))

* Fix python_version quoting.
([`5ebbb66`](https://github.com/OZI-Project/blastpipe/commit/5ebbb66719db5e0824e303f69094e4d03fb032a3))

* Fix missing requirements.in and move repo files.
([`0c14f63`](https://github.com/OZI-Project/blastpipe/commit/0c14f631fd6bda9a0b2267a2f199ce75298cd2ea))


### 🔨 Updated Scripts

*  Add dist script.
([`432c94f`](https://github.com/OZI-Project/blastpipe/commit/432c94fe7a839cd5034a6f352a0e930e24f0e61c))

*  Update OZI workflow. — rjdbcm &lt;rjdbcm@mail.umkc.edu&gt;
([`d9df1c6`](https://github.com/OZI-Project/blastpipe/commit/d9df1c64231fc797e5bff40a62d449d0ce552319))

*  Update for re-integration with OZI.
([`58189c2`](https://github.com/OZI-Project/blastpipe/commit/58189c293f4badb35be34b2f972ce96e639ecab1))


### Other


* Delete ozi subproject folder
([`8829084`](https://github.com/OZI-Project/blastpipe/commit/88290840d8635f7f44d512595821837bd7f2cf3a))

* Update subproject ref — rjdbcm &lt;rjdbcm@mail.umkc.edu&gt;
([`4b614f5`](https://github.com/OZI-Project/blastpipe/commit/4b614f55641a997b2d170b9fa29054b1c0e0df15))

* OZI wrap update — rjdbcm &lt;rjdbcm@mail.umkc.edu&gt;
([`ad127ad`](https://github.com/OZI-Project/blastpipe/commit/ad127ad13d9ef0ce90e63b844d8262df98ce5acb))

* Merge branch &#39;dev&#39; into main — Eden Rose, MSc &lt;rjdbcm@outlook.com&gt;
([`3409ae7`](https://github.com/OZI-Project/blastpipe/commit/3409ae79b6f19c953932d9b33726c649e4b44910))

* Merge pull request #3 from OZI-Project/dependabot/github_actions/ossf/scorecard-action-2.3.1

Bump ossf/scorecard-action from 2.0.6 to 2.3.1
([`e6a5097`](https://github.com/OZI-Project/blastpipe/commit/e6a5097fc1cfb7320d4ef61886da503eab950f27))

* Bump ossf/scorecard-action from 2.0.6 to 2.3.1

Bumps [ossf/scorecard-action](https://github.com/ossf/scorecard-action) from 2.0.6 to 2.3.1.
- [Release notes](https://github.com/ossf/scorecard-action/releases)
- [Changelog](https://github.com/ossf/scorecard-action/blob/main/RELEASE.md)
- [Commits](https://github.com/ossf/scorecard-action/compare/99c53751e09b9529366343771cc321ec74e9bd3d...0864cf19026789058feabb7e87baa5f140aac736)


updated-dependencies:
- dependency-name: ossf/scorecard-action
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`d9066ae`](https://github.com/OZI-Project/blastpipe/commit/d9066ae5da3fc0fff83b638d4b04add7e9843874))

* Merge pull request #5 from OZI-Project/dependabot/github_actions/python-semantic-release/python-semantic-release-8.7.2

Bump python-semantic-release/python-semantic-release from 8.0.8 to 8.7.2
([`c0c2278`](https://github.com/OZI-Project/blastpipe/commit/c0c2278a5ed02d338568a01c25c566ca2915e548))

* Bump python-semantic-release/python-semantic-release from 8.0.8 to 8.7.2

Bumps [python-semantic-release/python-semantic-release](https://github.com/python-semantic-release/python-semantic-release) from 8.0.8 to 8.7.2.
- [Release notes](https://github.com/python-semantic-release/python-semantic-release/releases)
- [Changelog](https://github.com/python-semantic-release/python-semantic-release/blob/master/CHANGELOG.md)
- [Commits](https://github.com/python-semantic-release/python-semantic-release/compare/3abfb7ac216b9ad439de24fda60eca84038e850e...1d2bbdf23aab816cd9d6e26f537b5cec9e39dede)


updated-dependencies:
- dependency-name: python-semantic-release/python-semantic-release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`251a792`](https://github.com/OZI-Project/blastpipe/commit/251a792644fcc6bc82378acdf9b273f01f6f7481))

* Merge pull request #4 from OZI-Project/dependabot/github_actions/actions/dependency-review-action-3.1.5

Bump actions/dependency-review-action from 2.5.1 to 3.1.5
([`aff1443`](https://github.com/OZI-Project/blastpipe/commit/aff144389ce85b8b5423d7d501f612d6d55ec2a6))

* Bump actions/dependency-review-action from 2.5.1 to 3.1.5

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 2.5.1 to 3.1.5.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/0efb1d1d84fc9633afcdaad14c485cbbc90ef46c...c74b580d73376b7750d3d2a50bfb8adc2c937507)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] &lt;support@github.com&gt;
([`ec0b1ac`](https://github.com/OZI-Project/blastpipe/commit/ec0b1ac220c8a9b5e66e8024e178f46f830e3b16))

* Merge pull request #6 from OZI-Project/dependabot/github_actions/actions/download-artifact-4.1.1

Bump actions/download-artifact from 3.0.2 to 4.1.1
([`110b1eb`](https://github.com/OZI-Project/blastpipe/commit/110b1eb3650c32da0b0a451fe125355186faa309))

* Bump actions/download-artifact from 3.0.2 to 4.1.1

Bumps [actions/download-artifact](https://github.com/actions/download-artifact) from 3.0.2 to 4.1.1.
- [Release notes](https://github.com/actions/download-artifact/releases)
- [Commits](https://github.com/actions/download-artifact/compare/9bc31d5ccc31df68ecc42ccf4149144866c47d8a...6b208ae046db98c579e8a3aa621ab581ff575935)


updated-dependencies:
- dependency-name: actions/download-artifact
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] &lt;support@github.com&gt;
([`c653bc9`](https://github.com/OZI-Project/blastpipe/commit/c653bc921a0bcd70d24e655441a5e054bc708da2))

* Merge pull request #7 from OZI-Project/dependabot/github_actions/actions/setup-python-5.0.0

Bump actions/setup-python from 4.7.0 to 5.0.0
([`8017ae8`](https://github.com/OZI-Project/blastpipe/commit/8017ae8b28f5dac1fd384fe4d76d02e41fbd0866))

* Bump actions/setup-python from 4.7.0 to 5.0.0

Bumps [actions/setup-python](https://github.com/actions/setup-python) from 4.7.0 to 5.0.0.
- [Release notes](https://github.com/actions/setup-python/releases)
- [Commits](https://github.com/actions/setup-python/compare/v4.7.0...0a5c61591373683505ea898e09a3ea4f39ef2b9c)


updated-dependencies:
- dependency-name: actions/setup-python
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] &lt;support@github.com&gt;
([`8652798`](https://github.com/OZI-Project/blastpipe/commit/8652798c37c4dd619f45ddefbb0ffc5150cfec8a))

* Merge branch &#39;main&#39; of https://github.com/rjdbcm/blastpipe
([`fb5be12`](https://github.com/OZI-Project/blastpipe/commit/fb5be121afeefa242a960b367ff13ad96e92e417))

* Merge pull request #38 from OZI-Project/dependabot/github_actions/pypa/gh-action-pypi-publish-1.8.14

⬆️ Bump pypa/gh-action-pypi-publish from 1.8.12 to 1.8.14
([`d9e14ec`](https://github.com/OZI-Project/blastpipe/commit/d9e14ecca9a45167af6b08fc4fd947c0dec0ab3c))

* Merge pull request #37 from OZI-Project/dependabot/github_actions/actions/download-artifact-4.1.4

⬆️ Bump actions/download-artifact from 4.1.3 to 4.1.4
([`c4ed292`](https://github.com/OZI-Project/blastpipe/commit/c4ed292ca6886f0dfb77b8b8fca456bf1bc8c2cb))

* Merge pull request #36 from OZI-Project/dependabot/github_actions/github/codeql-action-3.24.6

⬆️ Bump github/codeql-action from 3.24.5 to 3.24.6
([`7885ef8`](https://github.com/OZI-Project/blastpipe/commit/7885ef835fe9cb8f1874fc0e1ece6a6d3cbb5309))

* Merge pull request #33 from OZI-Project/dependabot/github_actions/python-semantic-release/python-semantic-release-9.1.1

⬆️ Bump python-semantic-release/python-semantic-release from 9.1.0 to 9.1.1
([`81d43e8`](https://github.com/OZI-Project/blastpipe/commit/81d43e8dded914f651bd4b1cec63b976331f8fbd))

* Merge pull request #34 from OZI-Project/dependabot/github_actions/actions/download-artifact-4.1.3

⬆️ Bump actions/download-artifact from 4.1.2 to 4.1.3
([`837d8e6`](https://github.com/OZI-Project/blastpipe/commit/837d8e6ab298ee5112d2485bc3994b3312ee3709))

* Merge pull request #35 from OZI-Project/dependabot/github_actions/pypa/gh-action-pypi-publish-1.8.12

⬆️ Bump pypa/gh-action-pypi-publish from 1.8.11 to 1.8.12
([`9f3ff4e`](https://github.com/OZI-Project/blastpipe/commit/9f3ff4e279148f6560d01926cd526c2852eedbe0))

* Merge pull request #26 from OZI-Project/dependabot/github_actions/python-semantic-release/python-semantic-release-9.1.0

⬆️ Bump python-semantic-release/python-semantic-release from 8.7.2 to 9.1.0
([`568bd95`](https://github.com/OZI-Project/blastpipe/commit/568bd952fd9dbb994b151d1cacf8c8e0ead28915))

* Merge pull request #21 from OZI-Project/dependabot/github_actions/actions/download-artifact-4.1.2

⬆️ Bump actions/download-artifact from 4.1.1 to 4.1.2
([`958130c`](https://github.com/OZI-Project/blastpipe/commit/958130c45cbe9b23085740bd5b1dc742babdf7e5))

* Merge pull request #19 from OZI-Project/dependabot/github_actions/step-security/harden-runner-2.7.0

⬆️ Bump step-security/harden-runner from 2.6.1 to 2.7.0
([`1e5effa`](https://github.com/OZI-Project/blastpipe/commit/1e5effa2e29ea9d97a93e639da1f347b6d97b93a))

* Merge pull request #30 from OZI-Project/dependabot/github_actions/actions/dependency-review-action-4.1.3

⬆️ Bump actions/dependency-review-action from 4.0.0 to 4.1.3
([`f93815c`](https://github.com/OZI-Project/blastpipe/commit/f93815c46b90be6e4881505b4341118fe1434657))

* Merge pull request #32 from OZI-Project/dependabot/github_actions/github/codeql-action-3.24.5

⬆️ Bump github/codeql-action from 3.23.1 to 3.24.5
([`6d2ec63`](https://github.com/OZI-Project/blastpipe/commit/6d2ec638c895192cf2c4ca4bb5fa2dfe19af4d1f))

* Merge pull request #16 from OZI-Project/dependabot/github_actions/github/codeql-action-3.23.1

Bump github/codeql-action from 2.23.0 to 3.23.1
([`1d53e65`](https://github.com/OZI-Project/blastpipe/commit/1d53e656eabeceaae2d6d51168fa791b7af8e73a))

* Bump github/codeql-action from 2.23.0 to 3.23.1

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 2.23.0 to 3.23.1.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/8b7fcbfac2aae0e6c24d9f9ebd5830b1290b18e4...0b21cf2492b6b02c465a3e5d7c473717ad7721ba)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] &lt;support@github.com&gt;
([`0fb81ce`](https://github.com/OZI-Project/blastpipe/commit/0fb81cea7671fb705811ac78983d3755a41beb57))

* Merge pull request #15 from OZI-Project/dependabot/github_actions/actions/setup-python-5.0.0

Bump actions/setup-python from 4.7.0 to 5.0.0
([`d4091cd`](https://github.com/OZI-Project/blastpipe/commit/d4091cddb58a51778fe62a0c36d1f83026976332))

* Bump actions/setup-python from 4.7.0 to 5.0.0

Bumps [actions/setup-python](https://github.com/actions/setup-python) from 4.7.0 to 5.0.0.
- [Release notes](https://github.com/actions/setup-python/releases)
- [Commits](https://github.com/actions/setup-python/compare/v4.7.0...0a5c61591373683505ea898e09a3ea4f39ef2b9c)


updated-dependencies:
- dependency-name: actions/setup-python
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] &lt;support@github.com&gt;
([`c3b2cbe`](https://github.com/OZI-Project/blastpipe/commit/c3b2cbedc4b06c6f84f6bd736d0868d71acf42e8))

* Merge pull request #14 from OZI-Project/dependabot/github_actions/ossf/scorecard-action-2.3.1

Bump ossf/scorecard-action from 2.0.6 to 2.3.1
([`2f8dba5`](https://github.com/OZI-Project/blastpipe/commit/2f8dba50b909deff0ef2c86243283e2481dd0ba6))

* Bump ossf/scorecard-action from 2.0.6 to 2.3.1

Bumps [ossf/scorecard-action](https://github.com/ossf/scorecard-action) from 2.0.6 to 2.3.1.
- [Release notes](https://github.com/ossf/scorecard-action/releases)
- [Changelog](https://github.com/ossf/scorecard-action/blob/main/RELEASE.md)
- [Commits](https://github.com/ossf/scorecard-action/compare/99c53751e09b9529366343771cc321ec74e9bd3d...0864cf19026789058feabb7e87baa5f140aac736)


updated-dependencies:
- dependency-name: ossf/scorecard-action
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`f5437e2`](https://github.com/OZI-Project/blastpipe/commit/f5437e21c4209eaf2829d19362076cfc92295c8c))

* Merge pull request #10 from OZI-Project/dependabot/github_actions/python-semantic-release/python-semantic-release-8.7.2

Bump python-semantic-release/python-semantic-release from 8.0.8 to 8.7.2
([`93983c7`](https://github.com/OZI-Project/blastpipe/commit/93983c79f2a5844239c9196c0bcddade8cfb1fb1))

* Bump python-semantic-release/python-semantic-release from 8.0.8 to 8.7.2

Bumps [python-semantic-release/python-semantic-release](https://github.com/python-semantic-release/python-semantic-release) from 8.0.8 to 8.7.2.
- [Release notes](https://github.com/python-semantic-release/python-semantic-release/releases)
- [Changelog](https://github.com/python-semantic-release/python-semantic-release/blob/master/CHANGELOG.md)
- [Commits](https://github.com/python-semantic-release/python-semantic-release/compare/3abfb7ac216b9ad439de24fda60eca84038e850e...1d2bbdf23aab816cd9d6e26f537b5cec9e39dede)


updated-dependencies:
- dependency-name: python-semantic-release/python-semantic-release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`9479e9e`](https://github.com/OZI-Project/blastpipe/commit/9479e9e027b68079ae51d154df13367fb03edf18))

* Merge pull request #11 from OZI-Project/dependabot/github_actions/pypa/gh-action-pypi-publish-1.8.11

Bump pypa/gh-action-pypi-publish from 1.4.2 to 1.8.11
([`a204e29`](https://github.com/OZI-Project/blastpipe/commit/a204e29152f1afe2cc5e1889cbfa9a78616b7124))

* Bump pypa/gh-action-pypi-publish from 1.4.2 to 1.8.11

Bumps [pypa/gh-action-pypi-publish](https://github.com/pypa/gh-action-pypi-publish) from 1.4.2 to 1.8.11.
- [Release notes](https://github.com/pypa/gh-action-pypi-publish/releases)
- [Commits](https://github.com/pypa/gh-action-pypi-publish/compare/27b31702a0e7fc50959f5ad993c78deac1bdfc29...2f6f737ca5f74c637829c0f5c3acd0e29ea5e8bf)


updated-dependencies:
- dependency-name: pypa/gh-action-pypi-publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`4a97e76`](https://github.com/OZI-Project/blastpipe/commit/4a97e76a27fb46c5643498285f90be0f9632b1d5))

* Merge pull request #12 from OZI-Project/dependabot/github_actions/actions/download-artifact-4.1.1

Bump actions/download-artifact from 3.0.2 to 4.1.1
([`35792ad`](https://github.com/OZI-Project/blastpipe/commit/35792adc87f9d6a156a44c28e1df7f997eaf1b6b))

* Bump actions/download-artifact from 3.0.2 to 4.1.1

Bumps [actions/download-artifact](https://github.com/actions/download-artifact) from 3.0.2 to 4.1.1.
- [Release notes](https://github.com/actions/download-artifact/releases)
- [Commits](https://github.com/actions/download-artifact/compare/9bc31d5ccc31df68ecc42ccf4149144866c47d8a...6b208ae046db98c579e8a3aa621ab581ff575935)


updated-dependencies:
- dependency-name: actions/download-artifact
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] &lt;support@github.com&gt;
([`9447dd4`](https://github.com/OZI-Project/blastpipe/commit/9447dd450c1f23fb85ded9971aac494bec4e63d7))

* Merge pull request #8 from OZI-Project/dependabot/github_actions/actions/checkout-4.1.1

Bump actions/checkout from 3.6.0 to 4.1.1
([`1b7db55`](https://github.com/OZI-Project/blastpipe/commit/1b7db558e1502bce5f400534eb2516d48f5e3d13))

* Bump actions/checkout from 3.6.0 to 4.1.1

Bumps [actions/checkout](https://github.com/actions/checkout) from 3.6.0 to 4.1.1.
- [Release notes](https://github.com/actions/checkout/releases)
- [Changelog](https://github.com/actions/checkout/blob/main/CHANGELOG.md)
- [Commits](https://github.com/actions/checkout/compare/f43a0e5ff2bd294095638e18286ca9a3d1956744...b4ffde65f46336ab88eb53be808477a3936bae11)


updated-dependencies:
- dependency-name: actions/checkout
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] &lt;support@github.com&gt;
([`863677d`](https://github.com/OZI-Project/blastpipe/commit/863677d6ce6c2cb501c38d11697723cd93681e61))

* Merge pull request #13 from OZI-Project/dependabot/github_actions/actions/dependency-review-action-4.0.0

Bump actions/dependency-review-action from 2.5.1 to 4.0.0
([`3a372e4`](https://github.com/OZI-Project/blastpipe/commit/3a372e4581c4f988a3cd1ecc082711b1026b70f6))

* Bump actions/dependency-review-action from 2.5.1 to 4.0.0

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 2.5.1 to 4.0.0.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/0efb1d1d84fc9633afcdaad14c485cbbc90ef46c...4901385134134e04cec5fbe5ddfe3b2c5bd5d976)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] &lt;support@github.com&gt;
([`864eac9`](https://github.com/OZI-Project/blastpipe/commit/864eac9442363922b19970195fd22731608c965c))

* Merge pull request #2 from step-security-bot/stepsecurity_remediation_1705263794

[StepSecurity] Apply security best practices
([`7b09010`](https://github.com/OZI-Project/blastpipe/commit/7b0901013cef0cd690e8e2dbfbee4414df73c6a1))

* [StepSecurity] Apply security best practices — StepSecurity Bot &lt;bot@stepsecurity.io&gt;
([`e79a366`](https://github.com/OZI-Project/blastpipe/commit/e79a366b88391af02f2e089cf6bedbac8088acbf))

* Bump for OZI changes &gt;0.0.235
([`ecaad6f`](https://github.com/OZI-Project/blastpipe/commit/ecaad6f00be73c0d9a4354ab60fa5f3809fc31e1))

* 👷(PKG-INFO): Bump Version.
([`e9d6426`](https://github.com/OZI-Project/blastpipe/commit/e9d6426c8fefc086a23f7a6957e7fb7476cdb63c))

## 2023.6.2 (2023-08-30)


### 🚸 Improved Usability

* (semantic-release): Fix commit parsing.
([`1936e88`](https://github.com/OZI-Project/blastpipe/commit/1936e88353b348c4bd279d7c0c47d5c6beb61843))


### Other


* 👷(PKG-INFO): Bump Version.
([`3d3794e`](https://github.com/OZI-Project/blastpipe/commit/3d3794ebc84870e261797cc12e0927e24d46e4fa))

## 2023.6.1 (2023-08-30)


### 🚑️ Hotfixed Issues

* (PKG-INFO): Correct Version at release.
([`e601bee`](https://github.com/OZI-Project/blastpipe/commit/e601bee6579b29d10c799e3b416ab01b17e6b3b2))


### Other


* 👷(gh-actions): Force patch release of fixed workflow.
([`ef6bd97`](https://github.com/OZI-Project/blastpipe/commit/ef6bd9788fd5c9b960f21c70adca5c106a3eb2fb))

* 👷(gh-actions): push PKG-INFO changes.
([`163a6a2`](https://github.com/OZI-Project/blastpipe/commit/163a6a23b816cafc7702c10487fa02e5a6c2fe54))

## 0.4.28 (2023-08-30)


### 🚑️ Hotfixed Issues

* 👷: Fix name of checkpoint job.
([`fb7af7b`](https://github.com/OZI-Project/blastpipe/commit/fb7af7bb67ab503c617e5d7df012eec07776d3a4))

* 🔧(meson): Project build files into meson build folder during configure.
([`494a77f`](https://github.com/OZI-Project/blastpipe/commit/494a77f588a16b20dae3d75bc83d101f7364347f))


### 🔨 Updated Configuration

* (meson): drop rst-lint and configure_file adaptation for now.
([`b8b541a`](https://github.com/OZI-Project/blastpipe/commit/b8b541aa80bbc2f3f3e94586f722cf0b6a5c6622))

* (tox): Fix tox-gh env names.
([`59ce6bb`](https://github.com/OZI-Project/blastpipe/commit/59ce6bbc2d3570e34c17877165fc594bb8159e6c))

* Update to use mypy and parity with OZI.
([`ecca7ca`](https://github.com/OZI-Project/blastpipe/commit/ecca7cab95357d4d3c96bd4b59c12aaf8382516e))


### Other


* Merge branch &#39;main&#39; of https://github.com/rjdbcm/blastpipe
([`6936fee`](https://github.com/OZI-Project/blastpipe/commit/6936fee4c9171b77be5af86cc7d494b3fe654862))

* 👷(gh-actions): Use ``${{ github.event.repository.name }} for file patterns.
([`c6a0e3e`](https://github.com/OZI-Project/blastpipe/commit/c6a0e3e1458ff8f79b43a88940bf3b5b1f31f4f1))

* 👷: Change .git permissions.
([`13e57f9`](https://github.com/OZI-Project/blastpipe/commit/13e57f9149a282c8f7e187ebed51d59cbcb997a2))

* Merge branch &#39;main&#39; of https://github.com/rjdbcm/blastpipe
([`de666bf`](https://github.com/OZI-Project/blastpipe/commit/de666bffdc7a51391a9b74f83967404a6a37807c))

* 👷(gh-actions): use ``${{ github.event.repository.name }}`` as repo name.
([`bc6ec63`](https://github.com/OZI-Project/blastpipe/commit/bc6ec637004c91fcdf6304abdf20c7ad9f50951c))

* Fixed: added back in rst-lint.
([`41463f3`](https://github.com/OZI-Project/blastpipe/commit/41463f3b70f89b358149c606e016f94bee4d8cf5))

* 👷(gh-actions): Drop windows runner.
([`3aa7b20`](https://github.com/OZI-Project/blastpipe/commit/3aa7b20a8c0f7f09819b5300ab13873ce47ba889))

* Delete wrapped subproject erroring OZI.
([`a396b6e`](https://github.com/OZI-Project/blastpipe/commit/a396b6ef7d95f7cc05a0e5b9a16b221edbfa95c7))

* fix tox args.
([`e1e5511`](https://github.com/OZI-Project/blastpipe/commit/e1e55113468f04bd4d4076b182658113ec83dae0))

* 🚑️(semantic-release): Args change for major version change 7 to 8.
([`21b89df`](https://github.com/OZI-Project/blastpipe/commit/21b89dfa81caf22f0c9ffeafe4b92bf45e2db694))

* 🎨(isort): isort stubfiles.
([`43cf07a`](https://github.com/OZI-Project/blastpipe/commit/43cf07ad7144e77fe1471d5e1dfed4d788370640))

* 👷: Update workflow drop OZI docs run.
([`a3e2f23`](https://github.com/OZI-Project/blastpipe/commit/a3e2f2354841c6d3702bec1affb465316ca4cfe3))

* Reduce number of README badges.
([`62f8b81`](https://github.com/OZI-Project/blastpipe/commit/62f8b811a5a36ae14bf6932893b6fddfe711a9ea))

* :pencil:: Fix line ending parity.
([`024f371`](https://github.com/OZI-Project/blastpipe/commit/024f3715b6f4c9ac9ce918d13ae98679929118f8))

* :pencil: Fix PKG-INFO parity to README.
([`a80fa85`](https://github.com/OZI-Project/blastpipe/commit/a80fa85d9a57a2c85d8e1b70cf5cf66861e8b250))

* 👷: Add new OZI standard workflow.
([`83dd01a`](https://github.com/OZI-Project/blastpipe/commit/83dd01aedf87b44a07d38fc89135a9e913445f3f))

* Merge branch &#39;main&#39; of https://github.com/rjdbcm/blastpipe
([`916b530`](https://github.com/OZI-Project/blastpipe/commit/916b5300fc026934e31b0a89d280138e65f4592d))

* Update README.rst
([`486b7bc`](https://github.com/OZI-Project/blastpipe/commit/486b7bc277d791999ab3aeb19ae29bdf110bb66f))

* Update README.rst
([`65749d5`](https://github.com/OZI-Project/blastpipe/commit/65749d516b23ab77270376bfedf028858583c4ed))

* 🔧(meson.build): add stubfiles to configfiles.
([`43a91a8`](https://github.com/OZI-Project/blastpipe/commit/43a91a87b052af4b1c320f786ef3c08e2f950a5b))

* 🔧(pyproject.toml): Update project configuration.
([`7af9a83`](https://github.com/OZI-Project/blastpipe/commit/7af9a836c92caf5619b182a32c42cf2409c64c41))

* ✏️(README.rst): Remove FOSSA erroneous mardown badge.
([`2a2138b`](https://github.com/OZI-Project/blastpipe/commit/2a2138b9925a210fe1968981ef12e52fb4da292b))

* 🏷️: Fully qualified types.
([`f043458`](https://github.com/OZI-Project/blastpipe/commit/f04345833649761073ab3ac6b7d2f8dd29aa7c11))

* 🚸: Added stubfiles to project.
([`a2d7f54`](https://github.com/OZI-Project/blastpipe/commit/a2d7f54fe96b139c729454627b4a77d3364e6a45))

* Merge pull request #1 from fossabot/add-license-scan-badge

Add license scan report and status
([`1a65603`](https://github.com/OZI-Project/blastpipe/commit/1a65603c9a69b6f6ad90b5d54b4fe5af527e4e0b))

* Add license scan report and status

Signed off by: fossabot &lt;badges@fossa.com&gt;
([`389d9dd`](https://github.com/OZI-Project/blastpipe/commit/389d9dd0b414b6aa0c26c90484514dba44bd8f7c))

* 🔊(CHANGELOG.md): add 0.4.27
([`aae61ee`](https://github.com/OZI-Project/blastpipe/commit/aae61ee89d08c44bac9a2183b41ad0cdd201f296))

* PKG-INFO Updated
([`29859d3`](https://github.com/OZI-Project/blastpipe/commit/29859d3d357d3b8c8b94cee35f67afc78f8cc7f5))

## 0.4.27 (2023-07-11)


### ✏️ Corrected Typos

* (complexity): # noqa: C901.
([`b9a6c35`](https://github.com/OZI-Project/blastpipe/commit/b9a6c357bfb269b1e3a03e0ffa9fe91720cbe996))


### Other


* 🚨(buffer.py): add no cover.
([`08be029`](https://github.com/OZI-Project/blastpipe/commit/08be02974ac93a2fd1e3d0cf9dbb25bbbad9349a))

* 🚨(__init__.py): add no cover.
([`9d2d6d2`](https://github.com/OZI-Project/blastpipe/commit/9d2d6d286a2a4282cb4973eba990394d0c1f0fbf))

* 🚨(loop.py): fix type union for Py39.
([`38fa215`](https://github.com/OZI-Project/blastpipe/commit/38fa21546a2e0215259da08b0272414f4cfa6512))

* 🚨(backports.py): noqa: E501 removed.
([`c355780`](https://github.com/OZI-Project/blastpipe/commit/c355780c2b9e70d3f35ce8b0c4a4c4f0a40579aa))

* 🚨(black): add ``-S``.
([`fef7f1e`](https://github.com/OZI-Project/blastpipe/commit/fef7f1ee30c116e9d691a541477bd671df141f29))

* ✅(test_fuzz.py:test_fuzz_while_raised): fixed positional-only args.
([`a74ef9f`](https://github.com/OZI-Project/blastpipe/commit/a74ef9fea1df8b4f0c3744463436368dca687553))

* 🚀(pyproject.toml): upload_to_release=true.
([`80f8f5f`](https://github.com/OZI-Project/blastpipe/commit/80f8f5f2769649ea7233d6ad2e9c51dabba30836))

* 🚨(project): Remove comments, fix minor linting issues.
([`1fa9491`](https://github.com/OZI-Project/blastpipe/commit/1fa9491db09cf5847bcca8e6bdca630c5e79a1ff))

* 🚨(project): fix typing and linting conflicts.
Also removed redundant comments.
([`fb293a9`](https://github.com/OZI-Project/blastpipe/commit/fb293a9fff1ec1f3b79b316784458db7efacb04b))

* 🏷️(project): add py.typed.
([`e608c33`](https://github.com/OZI-Project/blastpipe/commit/e608c33787c62b79536bef056067653e8ff9b52e))

* 🚨(project): Fix style linting.
Switched to black -S.
([`6689af8`](https://github.com/OZI-Project/blastpipe/commit/6689af8498454c0d87f904078581e3a6ef7f16ac))

* 🔊(CHANGELOG.md): add 0.4.26.
([`f7e2fc2`](https://github.com/OZI-Project/blastpipe/commit/f7e2fc2bfef1c7cf36ad54f47daa6772cce56a28))

* PKG-INFO Updated
([`eec299a`](https://github.com/OZI-Project/blastpipe/commit/eec299a59116d296196ec6592d52fd47abd3b772))

## 0.4.26 (2023-07-05)


### Other


* 🔨 changelog
([`34ff55a`](https://github.com/OZI-Project/blastpipe/commit/34ff55a9d7d4567065d9da1f82f616bc08a28edf))

* PKG-INFO Updated
([`4046a0b`](https://github.com/OZI-Project/blastpipe/commit/4046a0bfc7ca7e9ec39badb68691f25023d1c1da))

* 🔨(meson.options): disable doc8 run for now.
([`16e3219`](https://github.com/OZI-Project/blastpipe/commit/16e3219ac85e11a7b744a708a4909309c6212755))

* merge
([`d17ef64`](https://github.com/OZI-Project/blastpipe/commit/d17ef64e2e3f3b6b005eb6130dfbc2aee67d92f6))

## 0.4.25 (2023-07-05)


### ✏️ Corrected Typos

* (pyproject.toml): defer sphinxawesome-theme to ozi.
([`b1e144d`](https://github.com/OZI-Project/blastpipe/commit/b1e144d050f04f3887b1d64ac6a4f7454585792a))

* (README.rst): use blastpipe badge not OZI.
([`7a71e70`](https://github.com/OZI-Project/blastpipe/commit/7a71e70618441555406c574633e49b5e842309c8))


### Other


* 🔨(meson.build): enable subprojects/docs
([`0cd6483`](https://github.com/OZI-Project/blastpipe/commit/0cd6483a734fa6cc8a973faacaafec163f5d2a8f))

* 🔨(meson.build): disable subprojects/docs
([`22f48fb`](https://github.com/OZI-Project/blastpipe/commit/22f48fb1c9e3dc0c127ad993256e9a16d1e8549c))

* 📝(README.rst): Add Contributing info.
([`96fec96`](https://github.com/OZI-Project/blastpipe/commit/96fec96befae2e886e7125c528b5a48a3b18019f))

* 👷semantic-release: pre_commit tox.
([`61b9362`](https://github.com/OZI-Project/blastpipe/commit/61b93629158e16697479312d91382d8e1b9c32ee))

* 🔇(CHANGELOG.md): Clean up version tags.
([`a3a50e2`](https://github.com/OZI-Project/blastpipe/commit/a3a50e2ae6826c1e57641a0d54ee0d69d229e7fe))

* PKG-INFO Updated
([`cf7cd18`](https://github.com/OZI-Project/blastpipe/commit/cf7cd18ea0aaed5182ad547b80efe791f2825967))

## 0.4.24 (2023-06-25)


### Other


* 🔨(semantic-release): git clean -dfX pre_commit.
([`230bb86`](https://github.com/OZI-Project/blastpipe/commit/230bb86a3e1899136fa7d1b854ccb12a0c986ca2))

* ✏️ GPLv3 compatible specifically.
([`54da9fd`](https://github.com/OZI-Project/blastpipe/commit/54da9fd4229ed8519e9f7586d0e05300634783c0))

* 🔊 Add 0.4.23 changes.
CHANGELOG.md should actually get release notes from now on.
([`cdefd70`](https://github.com/OZI-Project/blastpipe/commit/cdefd70c105036b5c43a7588a2f47ecad9316a55))

* PKG-INFO Updated
([`55177f6`](https://github.com/OZI-Project/blastpipe/commit/55177f626333cf0322f0d89f0ff715f7cad10180))

## 0.4.23 (2023-06-24)


### Other


* 📦️ Use OZI pacakge.
([`52044b0`](https://github.com/OZI-Project/blastpipe/commit/52044b0802dc1988024d4c1d5f5d5d35f94c4531))

* PKG-INFO Updated
([`f80b3da`](https://github.com/OZI-Project/blastpipe/commit/f80b3da157f4a083922832e621b949a477238972))

## 0.4.22 (2023-06-23)


### Other


* ✏️ fix hanging continuation.
([`4b2b46d`](https://github.com/OZI-Project/blastpipe/commit/4b2b46d6357ca11606d62e2b30435e8b098cf095))

## 0.4.21 (2023-06-23)


### Other


* 🐛 add changes to Changelog.
([`012d5ff`](https://github.com/OZI-Project/blastpipe/commit/012d5ffd0c9f6adfed2372251c4afe90688d37eb))

* PKG-INFO Updated
([`5c84048`](https://github.com/OZI-Project/blastpipe/commit/5c840485844fabc70b91c5be67d7b60ab4b864b0))

## 0.4.20 (2023-06-22)


### Other


* 🚸 full commit local version before sdist.
([`77173e3`](https://github.com/OZI-Project/blastpipe/commit/77173e3d2e564b97bfbb584066e49849b355b845))

## 0.4.19 (2023-06-22)


### Other


* 🚸 git add PKG-INFO.
([`08f5272`](https://github.com/OZI-Project/blastpipe/commit/08f5272f6a7a7513204c8c92221b451aa2c16c0a))

## 0.4.18 (2023-06-22)


### Other


* 🚸 do dirty build.
([`357bafe`](https://github.com/OZI-Project/blastpipe/commit/357bafe06ec20c144c0254894692646c7921e4c9))

## 0.4.17 (2023-06-22)


### Other


* 🚸 No stash between setup and dist.
([`efcb2ab`](https://github.com/OZI-Project/blastpipe/commit/efcb2ab3bd76cdcacd2cf828155e1fff85b1336e))

## 0.4.16 (2023-06-22)


### 🍱


* (semantic-release) setuptools_scm Version&gt;PKG-INFO
([`2bf1900`](https://github.com/OZI-Project/blastpipe/commit/2bf19003dadb04df4d1e920850751b7b8a0b30dd))


### Other


* 🚸 PKG-INFO no commit
([`0f743f0`](https://github.com/OZI-Project/blastpipe/commit/0f743f098618f5819a23256a06835c650ca578f5))

## 0.4.15 (2023-06-22)


### Other


* 🚸 fix PKG-INFO typo.
([`13992dc`](https://github.com/OZI-Project/blastpipe/commit/13992dcaae1b437d2e33baccb399b4204dd1c7ac))

## 0.4.14 (2023-06-22)


### 🍱


* (semantic-release) setuptools_scm Version&gt;PKG-DATA
([`0dc0387`](https://github.com/OZI-Project/blastpipe/commit/0dc03878acdd01a15da70e1119e99da01d0f1ad7))


### Other


* 🚸 fix typo in git commit.
([`31ee152`](https://github.com/OZI-Project/blastpipe/commit/31ee152680c08fdaa4ef179cf448ff8e9677745d))

* 🚸 don&#39;t commit -a.
([`88f8ba1`](https://github.com/OZI-Project/blastpipe/commit/88f8ba1c51d16c5cd3242b720423ed3f0e77924a))

* 🚸 don&#39;t push next version.
([`31269d9`](https://github.com/OZI-Project/blastpipe/commit/31269d900315a2b62b16d6f9b7c53bdd6c1afc15))

## 0.4.13 (2023-06-22)


### 🍱


* (semantic-release) setuptools_scm Version&gt;PKG-DATA
([`14dbbda`](https://github.com/OZI-Project/blastpipe/commit/14dbbda4b7c44a5afc6b8b2141d8041c2db534ed))


### Other


* 🚸 stash after pyc_wheel.
([`84db1e4`](https://github.com/OZI-Project/blastpipe/commit/84db1e49113d6b3144894454ead306f4eae163e7))

## 0.4.12 (2023-06-22)


### Other


* 🚸 early commit add and push version.
([`feea008`](https://github.com/OZI-Project/blastpipe/commit/feea008a4c49cfbc3713442d463e72687ae14ca2))

## 0.4.11 (2023-06-22)


### Other


* 🚸 commit version &amp; push
([`1c9d76b`](https://github.com/OZI-Project/blastpipe/commit/1c9d76b6743f92ff8bf79000b4ae638ee3bad4ba))

## 0.4.10 (2023-06-22)


### Other


* 🚸 sync changes.
([`1d5691e`](https://github.com/OZI-Project/blastpipe/commit/1d5691eb045924930dd2eaa084ceadd9196e3cdd))

## 0.4.9 (2023-06-22)


### Other


* 🚸 try once more.
([`c758fef`](https://github.com/OZI-Project/blastpipe/commit/c758fef4ce8cd8bda418c5c9386fcafb7ae3dd1c))

## 0.4.8 (2023-06-22)


### Other


* 🚸 actually add changes.
([`2463283`](https://github.com/OZI-Project/blastpipe/commit/2463283c6c2e6f18904214968cba40e0da3c5a72))

## 0.4.7 (2023-06-22)


### 🍱


* (semantic-release) setuptools_scm Version&gt;PKG-DATA
([`43410f2`](https://github.com/OZI-Project/blastpipe/commit/43410f2e3bb20f0fa5287613e5c430a97afd55f7))


### Other


* 🚸 try version bump again...
([`7dd9d19`](https://github.com/OZI-Project/blastpipe/commit/7dd9d194c4200d4aa905642d53b15137da23c718))

## 0.4.6 (2023-06-21)


### 🍱


* (semantic-release) setuptools_scm Version&gt;PKG-DATA
([`28aceae`](https://github.com/OZI-Project/blastpipe/commit/28aceae28d1fd1833e4c61efd928df414ac57d4f))

## 0.4.5 (2023-06-21)


### 🍱


* (semantic-release) setuptools_scm Version&gt;PKG-DATA
([`756e3f5`](https://github.com/OZI-Project/blastpipe/commit/756e3f55d1e393b8055f8705bb563525e94159f0))


### Other


* don&#39;t stash wheel bump.
([`a9ca7d8`](https://github.com/OZI-Project/blastpipe/commit/a9ca7d8171535ce0e29ed08874bc674a048d8e6b))

## 0.4.4 (2023-06-21)


### 🍱


* (semantic-release) setuptools_scm Version&gt;PKG-DATA
([`e0671e1`](https://github.com/OZI-Project/blastpipe/commit/e0671e1a5a533090db1bff0e6a84d49064e354e8))


### Other


* Addition for release.
([`4be428d`](https://github.com/OZI-Project/blastpipe/commit/4be428d9ef2c61bdae3f8c39d56694dd058a7cb9))

## 0.4.3 (2023-06-21)


### 🍱


* (semantic-release) setuptools_scm Version&gt;PKG-DATA
([`6ea7cae`](https://github.com/OZI-Project/blastpipe/commit/6ea7cae0729dfeb4294fd68cbc8e292db662d6c4))

## 0.4.2 (2023-06-21)


### 🍱


* (semantic-release) setuptools_scm Version&gt;PKG-DATA
([`2477f60`](https://github.com/OZI-Project/blastpipe/commit/2477f60591f39346d11f1d5e7f3b924633aa8c81))

## 0.4.1 (2023-06-21)


### 🍱


* (semantic-release) setuptools_scm Version&gt;PKG-DATA
([`1371457`](https://github.com/OZI-Project/blastpipe/commit/13714571866a451a4fea6af9fa174ca5c88656ac))


### Other


* PKG-DATA update
([`f6b23ec`](https://github.com/OZI-Project/blastpipe/commit/f6b23ecf038c684fcc8d81d948e7dc8770c476a6))

* 🚸 add whitespace before PyPI metadata message.
([`815b811`](https://github.com/OZI-Project/blastpipe/commit/815b81179a9d4e317a735df6b7923c04c55abaf4))

## 0.4.0 (2023-06-21)


### 🍱


* (semantic-release) setuptools_scm Version&gt;PKG-DATA
([`b372b52`](https://github.com/OZI-Project/blastpipe/commit/b372b52aae5a4c83f7431928b8e832dd204c0b26))

## 0.3.16 (2023-06-21)


### 🍱


* (semantic-release) setuptools_scm Version&gt;PKG-DATA
([`343cbb9`](https://github.com/OZI-Project/blastpipe/commit/343cbb99ee4cb1d7e12f039cb7fb6e040a6ba984))


### Other


* 🍱 include README.rst in pyproject.
([`615c4d4`](https://github.com/OZI-Project/blastpipe/commit/615c4d40ae5385f5fb80d9accdf6bc9f44509b3f))

## 0.3.15 (2023-06-21)


### Other


* 🔧 Automate git add PKG-DATA.
([`43e17f6`](https://github.com/OZI-Project/blastpipe/commit/43e17f6ff70b9705b46e8c2a1fbbadf8ed52b13e))

## 0.3.14 (2023-06-21)


### Other


* 🔧 Use git add PKG-info.
([`6951901`](https://github.com/OZI-Project/blastpipe/commit/695190126146b11dfa94e747333a6eb8dd552534))

## 0.3.13 (2023-06-21)


### Other


* 🔧(semantic-release) commit PKG-DATA after unstash.
([`b92752f`](https://github.com/OZI-Project/blastpipe/commit/b92752ff574a12d4511f31d552f1f884dbcc5898))

## 0.3.12 (2023-06-21)


### Other


* 🔧 stash and pop strategy for clean versioned build.
([`714e2ba`](https://github.com/OZI-Project/blastpipe/commit/714e2bae92198dc4d45d2c4aae81924a83b046c4))

* scm version
([`d40046c`](https://github.com/OZI-Project/blastpipe/commit/d40046ca72f48820dc37e4f777251ac45cdd535f))

* manual commits.
([`67d67f5`](https://github.com/OZI-Project/blastpipe/commit/67d67f56d94492400623aa3290bd5d745d250065))

* SCM version
([`3631f59`](https://github.com/OZI-Project/blastpipe/commit/3631f59a07cb201f4cbd09978f29d38a94d62015))

* SCM version
([`3fc05b7`](https://github.com/OZI-Project/blastpipe/commit/3fc05b7d1f5897ceb5c99cccc469267ef2e542be))

* 🔨 use correct path.
([`a7f417f`](https://github.com/OZI-Project/blastpipe/commit/a7f417f1ed8ea43c2e674ddc5cd92b0d987b8fe7))

* 🔨 try commit without push.
([`7f05598`](https://github.com/OZI-Project/blastpipe/commit/7f05598081ecf6cb0a99b3f67f7d6af301c8b0e0))

* 🔨 add dist git commit version.
([`58d5622`](https://github.com/OZI-Project/blastpipe/commit/58d5622db85135b2db4d8061943aac61520591aa))

* 🔨 Use a transparent PKG-INFO file.
([`a413e6a`](https://github.com/OZI-Project/blastpipe/commit/a413e6acd3dd92629c408111456591e0050db925))

* 🔨 fix source dist
([`ec8ff8e`](https://github.com/OZI-Project/blastpipe/commit/ec8ff8e99213134a99c541a730d5f318df7700e0))

* 🔥 remove glue script.
([`177afc9`](https://github.com/OZI-Project/blastpipe/commit/177afc9932ba22bad02d314297adbebd8234c99b))

* fix glue plz
([`e2468f9`](https://github.com/OZI-Project/blastpipe/commit/e2468f93722021248cf215f075c2ed8e5eb873b9))

* fix glue scripts
([`9884ad6`](https://github.com/OZI-Project/blastpipe/commit/9884ad6e6ddd1d64b58b4a3a51d243a0fb47972d))

## 0.3.11 (2023-06-20)


### Other


* 🔨 try to again fix glue.
([`018333f`](https://github.com/OZI-Project/blastpipe/commit/018333f9b8d6a46eefe5b1efe3ffb44d9f615100))

## 0.3.10 (2023-06-20)


### Other


* 🔨 fix glue to give informative failures.
([`b220a9e`](https://github.com/OZI-Project/blastpipe/commit/b220a9ead2f55f43f92620c8654e2988cde94758))

## 0.3.9 (2023-06-20)


### Other


* 🔨 finalized fixed glue script.
([`6115ae4`](https://github.com/OZI-Project/blastpipe/commit/6115ae4a357ef7a463897cf08bd096c2e598f05b))

* 🔨 add glue script for dist.
([`b5b87ce`](https://github.com/OZI-Project/blastpipe/commit/b5b87ce8d7ad4834660a2f50cd9f810f239cee54))

* Changelog commit
([`6f9f8b7`](https://github.com/OZI-Project/blastpipe/commit/6f9f8b71e277b40cbd5b199447f272841509bcd7))

## 0.3.8 (2023-06-20)


### Other


* 🔧 only build wheel with `build`.
([`808940d`](https://github.com/OZI-Project/blastpipe/commit/808940d6fb8b337a7d00ab5387c52257a8a96780))

## 0.3.7 (2023-06-20)


### Other


* 🔧 manually build sdist.
([`39668a2`](https://github.com/OZI-Project/blastpipe/commit/39668a242c823e20ada95892bd56b71e48c3d88f))

## 0.3.6 (2023-06-20)


### Other


* 🔧 try double quoting meson-options.
([`18ffb60`](https://github.com/OZI-Project/blastpipe/commit/18ffb60338385b441c77724e96902bfca7fba062))

## 0.3.5 (2023-06-20)


### Other


* 🔧 add dist-args=&#39;--formats gztar&#39;
([`a499611`](https://github.com/OZI-Project/blastpipe/commit/a49961100404e3e9797bd0c466d8a678f2a30653))

## 0.3.4 (2023-06-20)


### Other


* 🔧 use gztar for sdist.
([`32f7567`](https://github.com/OZI-Project/blastpipe/commit/32f7567636fea14fd985ea146a5e960a272e2739))

## 0.3.3 (2023-06-20)


### Other


* 👷 add dist/*tar.gz to release.
([`c98d198`](https://github.com/OZI-Project/blastpipe/commit/c98d198ea350f35d46085927525daf157d8e36ea))

* 👷 build wheel and sdist.
([`ec543a4`](https://github.com/OZI-Project/blastpipe/commit/ec543a4ed82ece555f7013b1ef0932fe4cb664d6))

## 0.3.2 (2023-06-20)


### Other


* 👷 stash and pop changelog for clean versioning.
([`8fcbd3f`](https://github.com/OZI-Project/blastpipe/commit/8fcbd3f4d34f660d257611f5dcf6078268818efa))

* Changelog updated
([`ae69bd4`](https://github.com/OZI-Project/blastpipe/commit/ae69bd4ac31ecad3f0225013bd8474b831c21260))

## 0.3.1 (2023-06-20)


### Other


* ✏️ actually push the changes to the repo.
([`7876abd`](https://github.com/OZI-Project/blastpipe/commit/7876abd5f5bb21e8052e7bae907f899475303e45))

* Changelog updated
([`022ab77`](https://github.com/OZI-Project/blastpipe/commit/022ab77c0cb9cadda63d34fd4bf8daff2c82460f))

## 0.3.0 (2023-06-20)


### Other


* ✏️ remove hanging continuation.
([`1e5fc65`](https://github.com/OZI-Project/blastpipe/commit/1e5fc654d04528b55cf27dbb91741324fcd79f94))

* ✏️ fix missing continuation line
([`e92da41`](https://github.com/OZI-Project/blastpipe/commit/e92da41ae197af9832102ee58cd2194f0e550c87))

* 👷 move CHANGELOG commit to build step.
([`af2b566`](https://github.com/OZI-Project/blastpipe/commit/af2b56658ae00acbbf3791eaecbb57aa5295edcd))

* 👷 don&#39;t remove dist on semantic-release for now.
([`1460ff7`](https://github.com/OZI-Project/blastpipe/commit/1460ff76f2c9fda74f34ccd6277ebdeab31303df))

* 👷 checkpoint
([`cf1f010`](https://github.com/OZI-Project/blastpipe/commit/cf1f01080c6429053c69133cd0a3542c39d89c3a))

* 👷 only build wheel and test sdist no package upload for now.
([`955f8d0`](https://github.com/OZI-Project/blastpipe/commit/955f8d0b94856cadbb67ea93ed5b08b8ca4c4e25))

## 0.2.6 (2023-06-19)


### Other


* 👷 no repo upload on bump.
([`6c89b38`](https://github.com/OZI-Project/blastpipe/commit/6c89b38dc152bb6fee2c9c1b7bfbcb5326e0f0f4))

## 0.2.5 (2023-06-19)


### Other


* revert readme section move
([`cac0748`](https://github.com/OZI-Project/blastpipe/commit/cac0748b875a923044a8f0ac8cda88aea7d9615a))

* proper readme
([`1351fbc`](https://github.com/OZI-Project/blastpipe/commit/1351fbc5e936f448afd49f9133780d0150c7a6a5))

## 0.2.4 (2023-06-19)


### Other


* 👷 commit_version_number = true
([`100955e`](https://github.com/OZI-Project/blastpipe/commit/100955e10548027e0c923fb5a58e3758f1bb13f4))

* changes
([`13237df`](https://github.com/OZI-Project/blastpipe/commit/13237df637ef3bd6ece61ed87c1b77eb8d53b8b0))

## 0.2.3 (2023-06-19)


### ✏️ Corrected Typos

*  changed version writeback for release.
([`29334d6`](https://github.com/OZI-Project/blastpipe/commit/29334d653c79d5300230924d823a5f50a94aa9e6))

*  escape escape char.
([`d0a935a`](https://github.com/OZI-Project/blastpipe/commit/d0a935aadb3f8eb600e0940d87d32703aafc6aa4))

*  add back version variable.
([`5367338`](https://github.com/OZI-Project/blastpipe/commit/5367338747133e74e50c592e91082b074c3ea755))


### Other


* change version regex
([`343bc20`](https://github.com/OZI-Project/blastpipe/commit/343bc2038bb8274e5e81b274fd9aa94ada96146d))

## 0.2.2 (2023-06-19)


### Other


* ✏️ switch to tag_only version source
([`0b0b86a`](https://github.com/OZI-Project/blastpipe/commit/0b0b86a18bf0138f16995c91d2731f0758f7df52))

* ✏️ use slash for pattern path
([`afb0271`](https://github.com/OZI-Project/blastpipe/commit/afb027127d13c1b262bed5e9d88ee54dfc96776e))

* 👷 add version package pattern
([`66a0f49`](https://github.com/OZI-Project/blastpipe/commit/66a0f496ed94c5f4d6394c61bc968c2960b7431c))

* 👷 switch to ci commit versioning
([`b8bd455`](https://github.com/OZI-Project/blastpipe/commit/b8bd455a25e19f737f77de536d96cb7b055d2c40))

## 0.2.1 (2023-06-19)


### Other


* Changes to release.
([`fd26a79`](https://github.com/OZI-Project/blastpipe/commit/fd26a79002be80fe8ee150950bd761f03a109d2a))

## 0.2.0 (2023-06-19)


### Other


* changelogged
([`af1cd00`](https://github.com/OZI-Project/blastpipe/commit/af1cd0033c9fbe0385c237de315cb4d52f866a60))

## 0.1.1 (2023-06-19)


### Other


* ✏️ Fix dist include_additional_files.
([`07c7a4a`](https://github.com/OZI-Project/blastpipe/commit/07c7a4a5d6df3eb6a8020d95639c37ef0ef43b22))

* 🚨 lint for release test.
([`a292ad7`](https://github.com/OZI-Project/blastpipe/commit/a292ad70d4d5c9bf43e5d079558ddaba0b7a837b))

* 🚀 add testpypi and github artifact upload
([`4594834`](https://github.com/OZI-Project/blastpipe/commit/4594834abfd840168e1a6e65b6ef6d4164030065))

* 👷 add meson test and dist steps to semantic-release.
([`c2230dc`](https://github.com/OZI-Project/blastpipe/commit/c2230dc994177874aeaab8944fc1611d2930a9ec))

* 🧑‍💻 __init__.py now supplies __version__.
Uses the version from importlib.metadata.
([`46705b7`](https://github.com/OZI-Project/blastpipe/commit/46705b7e6090dc897f198868a3527d19064f19d4))

* 🔨  scm_version updates.
Meson writes fallback version and project name to pyproject.toml at dist time.
([`1c7ccc8`](https://github.com/OZI-Project/blastpipe/commit/1c7ccc87500c3b2def2fd19e128f7b996201ea88))

* 🚚 move vscode settings to subprojects/dev/ide
([`bd3a848`](https://github.com/OZI-Project/blastpipe/commit/bd3a848a7ddbf2b7b14aab3ec1a8823b8120073c))

* 👷🔧 added conf.py configuration template for docs.
([`1cbe295`](https://github.com/OZI-Project/blastpipe/commit/1cbe295ebc7a0ecdfa7efbf43c291114ea12e8d9))

* 🔨 docs no longer build_by_default.
([`12c4c6a`](https://github.com/OZI-Project/blastpipe/commit/12c4c6a2eea6f2b1e6ddf073c8d4cc26d6ac6ac6))

* 📄 Add license info to all remaining files
([`9cc6c02`](https://github.com/OZI-Project/blastpipe/commit/9cc6c027c826b868dbb7c3e399de5b7782fef698))

* 🔧 use fs.copyfile() instead of configure_file()
([`8936ae3`](https://github.com/OZI-Project/blastpipe/commit/8936ae3ce89f767410f1002dc09b39e2ddd6a214))

* Added 0.1.0 changes.
([`6b92237`](https://github.com/OZI-Project/blastpipe/commit/6b92237ad0ab02f4dbc56f6c8e922fc523f25ac2))

## 0.1.0 (2023-06-17)


### 💥


*  : Remove Partial Function Tail Call
Removed the partial function tail call optimization.
([`75934ce`](https://github.com/OZI-Project/blastpipe/commit/75934ce0d3210b2ff43e059405cb104ca27cda01))

*  Remove REST server
This code is not able to be attributed to a license.
([`a7507eb`](https://github.com/OZI-Project/blastpipe/commit/a7507eb105c0739e9e195ae10302c88cfde87e1b))


### 🐛 Fixed Bugs

*  : Fix meson sources
Removed rest35.py
([`de437f2`](https://github.com/OZI-Project/blastpipe/commit/de437f2b96146094e761bf28c2f2b3a041fe52c0))


### 📈


*  : Add tests/test_tailcall.py
Added some unit tests.
([`2740872`](https://github.com/OZI-Project/blastpipe/commit/2740872f57ce9b452e6f4dbad8bc65545851652d))


### Other


* ✏️ Ignore build*/.
([`ae71fa4`](https://github.com/OZI-Project/blastpipe/commit/ae71fa4f4401f3a391511b210cfc9ba798a4912d))

* 🔨 Change sigstore test arg default to --version.
([`932da60`](https://github.com/OZI-Project/blastpipe/commit/932da604a67a18d9d171f2072b4cf268335c6c38))

* 🔨 pyproject tox
([`55667cf`](https://github.com/OZI-Project/blastpipe/commit/55667cf52fec23f8edbc0938a2dd881c8b25e762))

* 🔨 tox build update.
([`12ee347`](https://github.com/OZI-Project/blastpipe/commit/12ee34790c32d469ec647a597843b75f46f121b7))

* 🔨 add tox setuptools_scm.
([`90c197f`](https://github.com/OZI-Project/blastpipe/commit/90c197f59d34f9779624512a0ef78c95380bbaed))

* 🔨 Simplify options structure for OZI.
([`2302e1c`](https://github.com/OZI-Project/blastpipe/commit/2302e1c1e52fad5ab8ea2025b058806ddd5affa8))

* ✏️ Only ignore toplevel dist.
([`85a1367`](https://github.com/OZI-Project/blastpipe/commit/85a1367d567630332906490df843c07a957eb1f6))

* 📝 Fix doc autogen.
([`733797d`](https://github.com/OZI-Project/blastpipe/commit/733797dff4cb0142e491d7f9c10a75c60e97c6bd))

* ✅ Simplified tests module structure.
([`4d3b48b`](https://github.com/OZI-Project/blastpipe/commit/4d3b48b7a8aa6d3c1e74d64c1fc2e644e8759f12))

* 📄 Switch to Apache-2.0 license.
([`e4169c4`](https://github.com/OZI-Project/blastpipe/commit/e4169c44b7482832e9b20ac810157ac2912af475))

* 👷 dev subproject is now a true project
([`c0409db`](https://github.com/OZI-Project/blastpipe/commit/c0409db38fa8212126bb498ea2320b8b571c8425))

* 🔧 subprojects/dev: Fix semantic-release version
([`70d47eb`](https://github.com/OZI-Project/blastpipe/commit/70d47ebf7833f65f5b2b3b3ed54e267a849d4ce9))

* 🔥 subprojects/dev/build.ninja: File deleted.
([`42d6ddb`](https://github.com/OZI-Project/blastpipe/commit/42d6ddbdab7173218f69c5bd888be11b8a36bfe5))

* ✏️(subprojects/dev): Remove TODO
([`c0e1f33`](https://github.com/OZI-Project/blastpipe/commit/c0e1f337ed84050bbad5d4e046aafa0f048adb14))

* 🔧(project): Change dev args
Log a dry run of semantic-release version.
([`c9ac619`](https://github.com/OZI-Project/blastpipe/commit/c9ac6192d32afc4225af95cea60728b5d7f430e0))

* ✅(tests): add test suite.
([`33d51d5`](https://github.com/OZI-Project/blastpipe/commit/33d51d5cdc4a594b4ed5bb883066872584b36050))

* 🚧📝➕(subprojects/docs): added documentation.
Added Meson driver for sphinx-build
WIP
([`79a4d12`](https://github.com/OZI-Project/blastpipe/commit/79a4d12c274aa4265b9d85b52fa9d289c1707827))

* 🚧🔨(subprojects/dev): Add snips and templates
Added source python of meson options.
([`a10ffd6`](https://github.com/OZI-Project/blastpipe/commit/a10ffd62df15b3dcc49ce0929ed11ecb4d6ca33a))

* 🔧🔨📦️🚚🍱🏗️(project): Update project config
Development build suite is now drivin entirely with Meson.
([`c5552df`](https://github.com/OZI-Project/blastpipe/commit/c5552df15ce6cc032c3bfe7a89f4923824893197))

* 🧑‍💻(vscode): add config
add settings.json
([`c8806e8`](https://github.com/OZI-Project/blastpipe/commit/c8806e8e338af1104c116e639cf5da00c9efc683))

* 🙈 project: Only ignore top level dist/
dist/ changes to ./dist/
([`41b4e74`](https://github.com/OZI-Project/blastpipe/commit/41b4e741ad5ca7cb20b4fc9a07512a3ca4d496a5))

* 📝 : Add docs folder
add meson built sphinx-build
([`5f4d704`](https://github.com/OZI-Project/blastpipe/commit/5f4d704635d568d83e7b7c1841eaac0881014e19))

* Add proper license attribution.
([`685fdf9`](https://github.com/OZI-Project/blastpipe/commit/685fdf9fed68c77105bb5a554578690a5b16074a))

* 📄 : Add malloc.py license
MIT required notice
([`9565c9b`](https://github.com/OZI-Project/blastpipe/commit/9565c9b6d5d0f893d85c0fd39c27ca933b6e1b0e))

* 📝 🚨 : Doc &amp; Lint
Added docstrings and fixed linter complaints.
([`cce2432`](https://github.com/OZI-Project/blastpipe/commit/cce2432a14e95a0a7d9e23f2154c506bc286b7ef))

* Fix pyproject.toml
([`de64858`](https://github.com/OZI-Project/blastpipe/commit/de64858766d40197bdaceecb31819881cf9654c5))

## 2023.6.0 (2023-05-06)


### Other


* fix again
([`c534fe1`](https://github.com/OZI-Project/blastpipe/commit/c534fe1dd9ad2b68622b721d4230220a7897b5b6))

* fix
([`32a4953`](https://github.com/OZI-Project/blastpipe/commit/32a4953d5995f43a41a5c104ec3fbf3555df68b4))

* fix pre_commit_command
([`38de9ca`](https://github.com/OZI-Project/blastpipe/commit/38de9caf32de315cdee8e6e9dd1d926df8e0f786))

* fix pre_commit_command
([`fbd412f`](https://github.com/OZI-Project/blastpipe/commit/fbd412f34fc3b3b67fd2793218ccb419cfb86a0c))

## 2023.5.0 (2023-05-05)


### Other


* Update to our standardized meson build.
([`3e2fdb2`](https://github.com/OZI-Project/blastpipe/commit/3e2fdb2f7c32e99af57e33c10ac2a836054bbd8d))

* meson build
([`2215879`](https://github.com/OZI-Project/blastpipe/commit/221587984b4e4bcf29ac6f9a19725e084777c712))

* update buffer to drain after each write
([`a953cab`](https://github.com/OZI-Project/blastpipe/commit/a953cab768e58d2ec4fc8acd5d77e6ed49235d9c))

* bump version
([`4457982`](https://github.com/OZI-Project/blastpipe/commit/445798218fdc06f6013e9584b2a5c18da30bf8be))

* add gitattribute version ref
([`ca42210`](https://github.com/OZI-Project/blastpipe/commit/ca42210ae6f34d1c64f87fd857e205194348ea0e))

* use -m pip call to build
([`dee7510`](https://github.com/OZI-Project/blastpipe/commit/dee75107ba28c5e28c86df656f111615e73d1f2e))

* specify package in pyproject
([`da1a0c2`](https://github.com/OZI-Project/blastpipe/commit/da1a0c224e8a8b5ab6f3c3b4f2af82a53578cf72))

* bump version
([`da8eb17`](https://github.com/OZI-Project/blastpipe/commit/da8eb172aeba06106bb9b33970e3d1faddcd8bd5))

* fix import
([`9fe2054`](https://github.com/OZI-Project/blastpipe/commit/9fe2054ea30252f67ec2b2c66a3bf9f997986de0))

* bump version to 2023.2.0b1
([`5bd8dd9`](https://github.com/OZI-Project/blastpipe/commit/5bd8dd9e07b2d0a0ec42d261786b2185b6dbb4b2))

* update build-system requirements
([`df6202b`](https://github.com/OZI-Project/blastpipe/commit/df6202bded6e531ab9788c15ae45e4c213568bc7))

* changelog update
([`771109c`](https://github.com/OZI-Project/blastpipe/commit/771109c247b2037e2ea5de69d9e4687064ed51cf))

* add changelog and scm
([`22a05f0`](https://github.com/OZI-Project/blastpipe/commit/22a05f078cbcd9fece946535fcb7fa832158de6c))

* add markdownlint and pre-commit hooks
([`0ab4aad`](https://github.com/OZI-Project/blastpipe/commit/0ab4aade442b5291f383ee5d58e04988768d3231))

* change project name to lemprex
([`37618c3`](https://github.com/OZI-Project/blastpipe/commit/37618c3f7f3c25073e5ae8df8ec6f213d0b2dae0))

* fixed version typo
([`9204c01`](https://github.com/OZI-Project/blastpipe/commit/9204c01d379a30081cac9cd70d5a18425949f3b2))

* added sequence.chr_union()
([`ec1a137`](https://github.com/OZI-Project/blastpipe/commit/ec1a137bd21baf454591d59ff67e52aaed8beee3))

* init
([`6a541a2`](https://github.com/OZI-Project/blastpipe/commit/6a541a2c6f9aea0fe16b55fdf8d5c3ee8198116b))
